# Python: 3.8.2 (tags/v3.8.2:7b3ab59, Feb 25 2020, 23:03:10) [MSC v.1916 64 bit (AMD64)]
# Library: scipy, version: 1.6.2
# Module: scipy.linalg._interpolative, version: $Revision: $
import typing
import builtins as _mod_builtins

__doc__: str
__file__: str
__name__: str
__package__: str
__version__: bytes
def id_srand(n) -> typing.Any:
    "r = id_srand(n)\n\nWrapper for ``id_srand``.\n\nParameters\n----------\nn : input int\n\nReturns\n-------\nr : rank-1 array('d') with bounds (n)\n"
    ...

def id_srandi(t) -> typing.Any:
    "id_srandi(t)\n\nWrapper for ``id_srandi``.\n\nParameters\n----------\nt : input rank-1 array('d') with bounds (55)\n"
    ...

def id_srando() -> typing.Any:
    'id_srando()\n\nWrapper for ``id_srando``.\n\n'
    ...

def idd_copycols(a, krank, list, m=..., n=...) -> typing.Any:
    "col = idd_copycols(a,krank,list,[m,n])\n\nWrapper for ``idd_copycols``.\n\nParameters\n----------\na : input rank-2 array('d') with bounds (m,n)\nkrank : input int\nlist : input rank-1 array('i') with bounds (*)\n\nOther Parameters\n----------------\nm : input int, optional\n    Default: shape(a,0)\nn : input int, optional\n    Default: shape(a,1)\n\nReturns\n-------\ncol : rank-2 array('d') with bounds (m,krank)\n"
    ...

def idd_diffsnorm(m, n, matvect, matvect2, matvec, matvec2, its, p1t=..., p2t=..., p3t=..., p4t=..., p1t2=..., p2t2=..., p3t2=..., p4t2=..., p1=..., p2=..., p3=..., p4=..., p12=..., p22=..., p32=..., p42=..., w=..., matvect_extra_args=..., matvect2_extra_args=..., matvec_extra_args=..., matvec2_extra_args=...) -> typing.Any:
    "snorm = idd_diffsnorm(m,n,matvect,matvect2,matvec,matvec2,its,[p1t,p2t,p3t,p4t,p1t2,p2t2,p3t2,p4t2,p1,p2,p3,p4,p12,p22,p32,p42,w,matvect_extra_args,matvect2_extra_args,matvec_extra_args,matvec2_extra_args])\n\nWrapper for ``idd_diffsnorm``.\n\nParameters\n----------\nm : input int\nn : input int\nmatvect : call-back function\nmatvect2 : call-back function\nmatvec : call-back function\nmatvec2 : call-back function\nits : input int\n\nOther Parameters\n----------------\nmatvect_extra_args : input tuple, optional\n    Default: ()\np1t : input float\np2t : input float\np3t : input float\np4t : input float\nmatvect2_extra_args : input tuple, optional\n    Default: ()\np1t2 : input float\np2t2 : input float\np3t2 : input float\np4t2 : input float\nmatvec_extra_args : input tuple, optional\n    Default: ()\np1 : input float\np2 : input float\np3 : input float\np4 : input float\nmatvec2_extra_args : input tuple, optional\n    Default: ()\np12 : input float\np22 : input float\np32 : input float\np42 : input float\nw : input rank-1 array('d') with bounds (3*(m+n))\n\nReturns\n-------\nsnorm : float\n\nNotes\n-----\nCall-back functions::\n\n  def matvect(x,[m,n,p1,p2,p3,p4]): return y\n  Required arguments:\n    x : input rank-1 array('d') with bounds (m)\n  Optional arguments:\n    m : input int, optional\n    Default: len(x)\n    n : input int\n    p1 : input float\n    p2 : input float\n    p3 : input float\n    p4 : input float\n  Return objects:\n    y : rank-1 array('d') with bounds (n)\n  def matvect2(x,[m,n,p1,p2,p3,p4]): return y\n  Required arguments:\n    x : input rank-1 array('d') with bounds (m)\n  Optional arguments:\n    m : input int, optional\n    Default: len(x)\n    n : input int\n    p1 : input float\n    p2 : input float\n    p3 : input float\n    p4 : input float\n  Return objects:\n    y : rank-1 array('d') with bounds (n)\n  def matvec(x,[n,m,p1,p2,p3,p4]): return y\n  Required arguments:\n    x : input rank-1 array('d') with bounds (n)\n  Optional arguments:\n    n : input int, optional\n    Default: len(x)\n    m : input int\n    p1 : input float\n    p2 : input float\n    p3 : input float\n    p4 : input float\n  Return objects:\n    y : rank-1 array('d') with bounds (m)\n  def matvec2(x,[n,m,p1,p2,p3,p4]): return y\n  Required arguments:\n    x : input rank-1 array('d') with bounds (n)\n  Optional arguments:\n    n : input int, optional\n    Default: len(x)\n    m : input int\n    p1 : input float\n    p2 : input float\n    p3 : input float\n    p4 : input float\n  Return objects:\n    y : rank-1 array('d') with bounds (m)\n"
    ...

def idd_estrank(eps, a, w, ra, m=..., n=...) -> typing.Any:
    "krank,ra = idd_estrank(eps,a,w,ra,[m,n])\n\nWrapper for ``idd_estrank``.\n\nParameters\n----------\neps : input float\na : input rank-2 array('d') with bounds (m,n)\nw : input rank-1 array('d') with bounds (17 * m + 70)\nra : input rank-1 array('d') with bounds (*)\n\nOther Parameters\n----------------\nm : input int, optional\n    Default: shape(a,0)\nn : input int, optional\n    Default: shape(a,1)\n\nReturns\n-------\nkrank : int\nra : rank-1 array('d') with bounds (*)\n"
    ...

def idd_findrank(eps, m, n, matvect, p1=..., p2=..., p3=..., p4=..., w=..., matvect_extra_args=...) -> typing.Any:
    "krank,ra,ier = idd_findrank(eps,m,n,matvect,[p1,p2,p3,p4,w,matvect_extra_args])\n\nWrapper for ``idd_findrank``.\n\nParameters\n----------\neps : input float\nm : input int\nn : input int\nmatvect : call-back function\n\nOther Parameters\n----------------\nmatvect_extra_args : input tuple, optional\n    Default: ()\np1 : input float\np2 : input float\np3 : input float\np4 : input float\nw : input rank-1 array('d') with bounds (m+2*n+1)\n\nReturns\n-------\nkrank : int\nra : rank-1 array('d') with bounds (2*n*min(m,n))\nier : int\n\nNotes\n-----\nCall-back functions::\n\n  def matvect(x,[m,n,p1,p2,p3,p4]): return y\n  Required arguments:\n    x : input rank-1 array('d') with bounds (m)\n  Optional arguments:\n    m : input int, optional\n    Default: len(x)\n    n : input int\n    p1 : input float\n    p2 : input float\n    p3 : input float\n    p4 : input float\n  Return objects:\n    y : rank-1 array('d') with bounds (n)\n"
    ...

def idd_frm(n, w, x, m=...) -> typing.Any:
    "y = idd_frm(n,w,x,[m])\n\nWrapper for ``idd_frm``.\n\nParameters\n----------\nn : input int\nw : input rank-1 array('d') with bounds (17 * m + 70)\nx : input rank-1 array('d') with bounds (m)\n\nOther Parameters\n----------------\nm : input int, optional\n    Default: len(x)\n\nReturns\n-------\ny : rank-1 array('d') with bounds (n)\n"
    ...

def idd_frmi(m) -> typing.Any:
    "n,w = idd_frmi(m)\n\nWrapper for ``idd_frmi``.\n\nParameters\n----------\nm : input int\n\nReturns\n-------\nn : int\nw : rank-1 array('d') with bounds (17 * m + 70)\n"
    ...

def idd_id2svd(b, list, proj, m=..., krank=..., n=..., w=...) -> typing.Any:
    "u,v,s,ier = idd_id2svd(b,list,proj,[m,krank,n,w])\n\nWrapper for ``idd_id2svd``.\n\nParameters\n----------\nb : input rank-2 array('d') with bounds (m,krank)\nlist : input rank-1 array('i') with bounds (n)\nproj : input rank-2 array('d') with bounds (krank,n-krank)\n\nOther Parameters\n----------------\nm : input int, optional\n    Default: shape(b,0)\nkrank : input int, optional\n    Default: shape(b,1)\nn : input int, optional\n    Default: len(list)\nw : input rank-1 array('d') with bounds ((krank+1)*(m+3*n)+26*pow(krank,2))\n\nReturns\n-------\nu : rank-2 array('d') with bounds (m,krank)\nv : rank-2 array('d') with bounds (n,krank)\ns : rank-1 array('d') with bounds (krank)\nier : int\n"
    ...

def idd_reconid(col, list, proj, m=..., krank=..., n=...) -> typing.Any:
    "approx = idd_reconid(col,list,proj,[m,krank,n])\n\nWrapper for ``idd_reconid``.\n\nParameters\n----------\ncol : input rank-2 array('d') with bounds (m,krank)\nlist : input rank-1 array('i') with bounds (n)\nproj : input rank-2 array('d') with bounds (krank,n-krank)\n\nOther Parameters\n----------------\nm : input int, optional\n    Default: shape(col,0)\nkrank : input int, optional\n    Default: shape(col,1)\nn : input int, optional\n    Default: len(list)\n\nReturns\n-------\napprox : rank-2 array('d') with bounds (m,n)\n"
    ...

def idd_reconint(list, proj, n=..., krank=...) -> typing.Any:
    "p = idd_reconint(list,proj,[n,krank])\n\nWrapper for ``idd_reconint``.\n\nParameters\n----------\nlist : input rank-1 array('i') with bounds (n)\nproj : input rank-2 array('d') with bounds (krank,n-krank)\n\nOther Parameters\n----------------\nn : input int, optional\n    Default: len(list)\nkrank : input int, optional\n    Default: shape(proj,0)\n\nReturns\n-------\np : rank-2 array('d') with bounds (krank,n)\n"
    ...

def idd_sfrm(l, n, w, x, m=...) -> typing.Any:
    "y = idd_sfrm(l,n,w,x,[m])\n\nWrapper for ``idd_sfrm``.\n\nParameters\n----------\nl : input int\nn : input int\nw : input rank-1 array('d') with bounds (27 * m + 90)\nx : input rank-1 array('d') with bounds (m)\n\nOther Parameters\n----------------\nm : input int, optional\n    Default: len(x)\n\nReturns\n-------\ny : rank-1 array('d') with bounds (l)\n"
    ...

def idd_sfrmi(l, m) -> typing.Any:
    "n,w = idd_sfrmi(l,m)\n\nWrapper for ``idd_sfrmi``.\n\nParameters\n----------\nl : input int\nm : input int\n\nReturns\n-------\nn : int\nw : rank-1 array('d') with bounds (27 * m + 90)\n"
    ...

def idd_snorm(m, n, matvect, matvec, its, p1t=..., p2t=..., p3t=..., p4t=..., p1=..., p2=..., p3=..., p4=..., u=..., matvect_extra_args=..., matvec_extra_args=...) -> typing.Any:
    "snorm,v = idd_snorm(m,n,matvect,matvec,its,[p1t,p2t,p3t,p4t,p1,p2,p3,p4,u,matvect_extra_args,matvec_extra_args])\n\nWrapper for ``idd_snorm``.\n\nParameters\n----------\nm : input int\nn : input int\nmatvect : call-back function\nmatvec : call-back function\nits : input int\n\nOther Parameters\n----------------\nmatvect_extra_args : input tuple, optional\n    Default: ()\np1t : input float\np2t : input float\np3t : input float\np4t : input float\nmatvec_extra_args : input tuple, optional\n    Default: ()\np1 : input float\np2 : input float\np3 : input float\np4 : input float\nu : input rank-1 array('d') with bounds (m)\n\nReturns\n-------\nsnorm : float\nv : rank-1 array('d') with bounds (n)\n\nNotes\n-----\nCall-back functions::\n\n  def matvect(x,[m,n,p1,p2,p3,p4]): return y\n  Required arguments:\n    x : input rank-1 array('d') with bounds (m)\n  Optional arguments:\n    m : input int, optional\n    Default: len(x)\n    n : input int\n    p1 : input float\n    p2 : input float\n    p3 : input float\n    p4 : input float\n  Return objects:\n    y : rank-1 array('d') with bounds (n)\n  def matvec(x,[n,m,p1,p2,p3,p4]): return y\n  Required arguments:\n    x : input rank-1 array('d') with bounds (n)\n  Optional arguments:\n    n : input int, optional\n    Default: len(x)\n    m : input int\n    p1 : input float\n    p2 : input float\n    p3 : input float\n    p4 : input float\n  Return objects:\n    y : rank-1 array('d') with bounds (m)\n"
    ...

def iddp_aid(eps, a, work, proj, m=..., n=...) -> typing.Any:
    "krank,list,proj = iddp_aid(eps,a,work,proj,[m,n])\n\nWrapper for ``iddp_aid``.\n\nParameters\n----------\neps : input float\na : input rank-2 array('d') with bounds (m,n)\nwork : input rank-1 array('d') with bounds (17 * m + 70)\nproj : input rank-1 array('d') with bounds (*)\n\nOther Parameters\n----------------\nm : input int, optional\n    Default: shape(a,0)\nn : input int, optional\n    Default: shape(a,1)\n\nReturns\n-------\nkrank : int\nlist : rank-1 array('i') with bounds (n)\nproj : rank-1 array('d') with bounds (*)\n"
    ...

def iddp_asvd(eps, a, winit, w, m=..., n=...) -> typing.Any:
    "krank,iu,iv,is,w,ier = iddp_asvd(eps,a,winit,w,[m,n])\n\nWrapper for ``iddp_asvd``.\n\nParameters\n----------\neps : input float\na : input rank-2 array('d') with bounds (m,n)\nwinit : input rank-1 array('d') with bounds (17 * m + 70)\nw : input rank-1 array('d') with bounds (*)\n\nOther Parameters\n----------------\nm : input int, optional\n    Default: shape(a,0)\nn : input int, optional\n    Default: shape(a,1)\n\nReturns\n-------\nkrank : int\niu : int\niv : int\nis : int\nw : rank-1 array('d') with bounds (*)\nier : int\n"
    ...

def iddp_id(eps, a, m=..., n=...) -> typing.Any:
    "krank,list,rnorms = iddp_id(eps,a,[m,n])\n\nWrapper for ``iddp_id``.\n\nParameters\n----------\neps : input float\na : input rank-2 array('d') with bounds (m,n)\n\nOther Parameters\n----------------\nm : input int, optional\n    Default: shape(a,0)\nn : input int, optional\n    Default: shape(a,1)\n\nReturns\n-------\nkrank : int\nlist : rank-1 array('i') with bounds (n)\nrnorms : rank-1 array('d') with bounds (n)\n"
    ...

def iddp_rid(eps, m, n, matvect, proj, p1=..., p2=..., p3=..., p4=..., matvect_extra_args=...) -> typing.Any:
    "krank,list,proj,ier = iddp_rid(eps,m,n,matvect,proj,[p1,p2,p3,p4,matvect_extra_args])\n\nWrapper for ``iddp_rid``.\n\nParameters\n----------\neps : input float\nm : input int\nn : input int\nmatvect : call-back function\nproj : input rank-1 array('d') with bounds (*)\n\nOther Parameters\n----------------\nmatvect_extra_args : input tuple, optional\n    Default: ()\np1 : input float\np2 : input float\np3 : input float\np4 : input float\n\nReturns\n-------\nkrank : int\nlist : rank-1 array('i') with bounds (n)\nproj : rank-1 array('d') with bounds (*)\nier : int\n\nNotes\n-----\nCall-back functions::\n\n  def matvect(x,[m,n,p1,p2,p3,p4]): return y\n  Required arguments:\n    x : input rank-1 array('d') with bounds (m)\n  Optional arguments:\n    m : input int, optional\n    Default: len(x)\n    n : input int\n    p1 : input float\n    p2 : input float\n    p3 : input float\n    p4 : input float\n  Return objects:\n    y : rank-1 array('d') with bounds (n)\n"
    ...

def iddp_rsvd(eps, m, n, matvect, matvec, p1t=..., p2t=..., p3t=..., p4t=..., p1=..., p2=..., p3=..., p4=..., matvect_extra_args=..., matvec_extra_args=...) -> typing.Any:
    "krank,iu,iv,is,w,ier = iddp_rsvd(eps,m,n,matvect,matvec,[p1t,p2t,p3t,p4t,p1,p2,p3,p4,matvect_extra_args,matvec_extra_args])\n\nWrapper for ``iddp_rsvd``.\n\nParameters\n----------\neps : input float\nm : input int\nn : input int\nmatvect : call-back function\nmatvec : call-back function\n\nOther Parameters\n----------------\nmatvect_extra_args : input tuple, optional\n    Default: ()\np1t : input float\np2t : input float\np3t : input float\np4t : input float\nmatvec_extra_args : input tuple, optional\n    Default: ()\np1 : input float\np2 : input float\np3 : input float\np4 : input float\n\nReturns\n-------\nkrank : int\niu : int\niv : int\nis : int\nw : rank-1 array('d') with bounds ((min(m,n)+1)*(3*m+5*n+1)+25*pow(min(m,n),2))\nier : int\n\nNotes\n-----\nCall-back functions::\n\n  def matvect(x,[m,n,p1,p2,p3,p4]): return y\n  Required arguments:\n    x : input rank-1 array('d') with bounds (m)\n  Optional arguments:\n    m : input int, optional\n    Default: len(x)\n    n : input int\n    p1 : input float\n    p2 : input float\n    p3 : input float\n    p4 : input float\n  Return objects:\n    y : rank-1 array('d') with bounds (n)\n  def matvec(x,[n,m,p1,p2,p3,p4]): return y\n  Required arguments:\n    x : input rank-1 array('d') with bounds (n)\n  Optional arguments:\n    n : input int, optional\n    Default: len(x)\n    m : input int\n    p1 : input float\n    p2 : input float\n    p3 : input float\n    p4 : input float\n  Return objects:\n    y : rank-1 array('d') with bounds (m)\n"
    ...

def iddp_svd(eps, a, m=..., n=...) -> typing.Any:
    "krank,iu,iv,is,w,ier = iddp_svd(eps,a,[m,n])\n\nWrapper for ``iddp_svd``.\n\nParameters\n----------\neps : input float\na : input rank-2 array('d') with bounds (m,n)\n\nOther Parameters\n----------------\nm : input int, optional\n    Default: shape(a,0)\nn : input int, optional\n    Default: shape(a,1)\n\nReturns\n-------\nkrank : int\niu : int\niv : int\nis : int\nw : rank-1 array('d') with bounds ((min(m,n)+1)*(m+2*n+9)+8*min(m,n)+15*pow(min(m,n),2))\nier : int\n"
    ...

def iddr_aid(a, krank, w, m=..., n=...) -> typing.Any:
    "list,proj = iddr_aid(a,krank,w,[m,n])\n\nWrapper for ``iddr_aid``.\n\nParameters\n----------\na : input rank-2 array('d') with bounds (m,n)\nkrank : input int\nw : input rank-1 array('d') with bounds ((2*krank+17)*n+27*m+100)\n\nOther Parameters\n----------------\nm : input int, optional\n    Default: shape(a,0)\nn : input int, optional\n    Default: shape(a,1)\n\nReturns\n-------\nlist : rank-1 array('i') with bounds (n)\nproj : rank-1 array('d') with bounds (max(krank*(n-krank),1))\n"
    ...

def iddr_aidi(m, n, krank) -> typing.Any:
    "w = iddr_aidi(m,n,krank)\n\nWrapper for ``iddr_aidi``.\n\nParameters\n----------\nm : input int\nn : input int\nkrank : input int\n\nReturns\n-------\nw : rank-1 array('d') with bounds ((2*krank+17)*n+27*m+100)\n"
    ...

def iddr_asvd(a, krank, w, m=..., n=...) -> typing.Any:
    "u,v,s,ier = iddr_asvd(a,krank,w,[m,n])\n\nWrapper for ``iddr_asvd``.\n\nParameters\n----------\na : input rank-2 array('d') with bounds (m,n)\nkrank : input int\nw : input rank-1 array('d') with bounds ((2*krank+28)*m+(6*krank+21)*n+25*pow(krank,2)+100)\n\nOther Parameters\n----------------\nm : input int, optional\n    Default: shape(a,0)\nn : input int, optional\n    Default: shape(a,1)\n\nReturns\n-------\nu : rank-2 array('d') with bounds (m,krank)\nv : rank-2 array('d') with bounds (n,krank)\ns : rank-1 array('d') with bounds (krank)\nier : int\n"
    ...

def iddr_id(a, krank, m=..., n=...) -> typing.Any:
    "list,rnorms = iddr_id(a,krank,[m,n])\n\nWrapper for ``iddr_id``.\n\nParameters\n----------\na : input rank-2 array('d') with bounds (m,n)\nkrank : input int\n\nOther Parameters\n----------------\nm : input int, optional\n    Default: shape(a,0)\nn : input int, optional\n    Default: shape(a,1)\n\nReturns\n-------\nlist : rank-1 array('i') with bounds (n)\nrnorms : rank-1 array('d') with bounds (n)\n"
    ...

def iddr_rid(m, n, matvect, krank, p1=..., p2=..., p3=..., p4=..., matvect_extra_args=...) -> typing.Any:
    "list,proj = iddr_rid(m,n,matvect,krank,[p1,p2,p3,p4,matvect_extra_args])\n\nWrapper for ``iddr_rid``.\n\nParameters\n----------\nm : input int\nn : input int\nmatvect : call-back function\nkrank : input int\n\nOther Parameters\n----------------\nmatvect_extra_args : input tuple, optional\n    Default: ()\np1 : input float\np2 : input float\np3 : input float\np4 : input float\n\nReturns\n-------\nlist : rank-1 array('i') with bounds (n)\nproj : rank-1 array('d') with bounds (m+(krank+3)*n)\n\nNotes\n-----\nCall-back functions::\n\n  def matvect(x,[m,n,p1,p2,p3,p4]): return y\n  Required arguments:\n    x : input rank-1 array('d') with bounds (m)\n  Optional arguments:\n    m : input int, optional\n    Default: len(x)\n    n : input int\n    p1 : input float\n    p2 : input float\n    p3 : input float\n    p4 : input float\n  Return objects:\n    y : rank-1 array('d') with bounds (n)\n"
    ...

def iddr_rsvd(m, n, matvect, matvec, krank, p1t=..., p2t=..., p3t=..., p4t=..., p1=..., p2=..., p3=..., p4=..., w=..., matvect_extra_args=..., matvec_extra_args=...) -> typing.Any:
    "u,v,s,ier = iddr_rsvd(m,n,matvect,matvec,krank,[p1t,p2t,p3t,p4t,p1,p2,p3,p4,w,matvect_extra_args,matvec_extra_args])\n\nWrapper for ``iddr_rsvd``.\n\nParameters\n----------\nm : input int\nn : input int\nmatvect : call-back function\nmatvec : call-back function\nkrank : input int\n\nOther Parameters\n----------------\nmatvect_extra_args : input tuple, optional\n    Default: ()\np1t : input float\np2t : input float\np3t : input float\np4t : input float\nmatvec_extra_args : input tuple, optional\n    Default: ()\np1 : input float\np2 : input float\np3 : input float\np4 : input float\nw : input rank-1 array('d') with bounds ((krank+1)*(2*m+4*n)+25*pow(krank,2))\n\nReturns\n-------\nu : rank-2 array('d') with bounds (m,krank)\nv : rank-2 array('d') with bounds (n,krank)\ns : rank-1 array('d') with bounds (krank)\nier : int\n\nNotes\n-----\nCall-back functions::\n\n  def matvect(x,[m,n,p1,p2,p3,p4]): return y\n  Required arguments:\n    x : input rank-1 array('d') with bounds (m)\n  Optional arguments:\n    m : input int, optional\n    Default: len(x)\n    n : input int\n    p1 : input float\n    p2 : input float\n    p3 : input float\n    p4 : input float\n  Return objects:\n    y : rank-1 array('d') with bounds (n)\n  def matvec(x,[n,m,p1,p2,p3,p4]): return y\n  Required arguments:\n    x : input rank-1 array('d') with bounds (n)\n  Optional arguments:\n    n : input int, optional\n    Default: len(x)\n    m : input int\n    p1 : input float\n    p2 : input float\n    p3 : input float\n    p4 : input float\n  Return objects:\n    y : rank-1 array('d') with bounds (m)\n"
    ...

def iddr_svd(a, krank, m=..., n=..., r=...) -> typing.Any:
    "u,v,s,ier = iddr_svd(a,krank,[m,n,r])\n\nWrapper for ``iddr_svd``.\n\nParameters\n----------\na : input rank-2 array('d') with bounds (m,n)\nkrank : input int\n\nOther Parameters\n----------------\nm : input int, optional\n    Default: shape(a,0)\nn : input int, optional\n    Default: shape(a,1)\nr : input rank-1 array('d') with bounds ((krank+2)*n+8*min(m,n)+15*pow(krank,2)+8*krank)\n\nReturns\n-------\nu : rank-2 array('d') with bounds (m,krank)\nv : rank-2 array('d') with bounds (n,krank)\ns : rank-1 array('d') with bounds (krank)\nier : int\n"
    ...

def idz_copycols(a, krank, list, m=..., n=...) -> typing.Any:
    "col = idz_copycols(a,krank,list,[m,n])\n\nWrapper for ``idz_copycols``.\n\nParameters\n----------\na : input rank-2 array('D') with bounds (m,n)\nkrank : input int\nlist : input rank-1 array('i') with bounds (*)\n\nOther Parameters\n----------------\nm : input int, optional\n    Default: shape(a,0)\nn : input int, optional\n    Default: shape(a,1)\n\nReturns\n-------\ncol : rank-2 array('D') with bounds (m,krank)\n"
    ...

def idz_diffsnorm(m, n, matveca, matveca2, matvec, matvec2, its, p1a=..., p2a=..., p3a=..., p4a=..., p1a2=..., p2a2=..., p3a2=..., p4a2=..., p1=..., p2=..., p3=..., p4=..., p12=..., p22=..., p32=..., p42=..., w=..., matveca_extra_args=..., matveca2_extra_args=..., matvec_extra_args=..., matvec2_extra_args=...) -> typing.Any:
    "snorm = idz_diffsnorm(m,n,matveca,matveca2,matvec,matvec2,its,[p1a,p2a,p3a,p4a,p1a2,p2a2,p3a2,p4a2,p1,p2,p3,p4,p12,p22,p32,p42,w,matveca_extra_args,matveca2_extra_args,matvec_extra_args,matvec2_extra_args])\n\nWrapper for ``idz_diffsnorm``.\n\nParameters\n----------\nm : input int\nn : input int\nmatveca : call-back function\nmatveca2 : call-back function\nmatvec : call-back function\nmatvec2 : call-back function\nits : input int\n\nOther Parameters\n----------------\nmatveca_extra_args : input tuple, optional\n    Default: ()\np1a : input complex\np2a : input complex\np3a : input complex\np4a : input complex\nmatveca2_extra_args : input tuple, optional\n    Default: ()\np1a2 : input complex\np2a2 : input complex\np3a2 : input complex\np4a2 : input complex\nmatvec_extra_args : input tuple, optional\n    Default: ()\np1 : input complex\np2 : input complex\np3 : input complex\np4 : input complex\nmatvec2_extra_args : input tuple, optional\n    Default: ()\np12 : input complex\np22 : input complex\np32 : input complex\np42 : input complex\nw : input rank-1 array('D') with bounds (3*(m+n))\n\nReturns\n-------\nsnorm : float\n\nNotes\n-----\nCall-back functions::\n\n  def matveca(x,[m,n,p1,p2,p3,p4]): return y\n  Required arguments:\n    x : input rank-1 array('D') with bounds (m)\n  Optional arguments:\n    m : input int, optional\n    Default: len(x)\n    n : input int\n    p1 : input complex\n    p2 : input complex\n    p3 : input complex\n    p4 : input complex\n  Return objects:\n    y : rank-1 array('D') with bounds (n)\n  def matveca2(x,[m,n,p1,p2,p3,p4]): return y\n  Required arguments:\n    x : input rank-1 array('D') with bounds (m)\n  Optional arguments:\n    m : input int, optional\n    Default: len(x)\n    n : input int\n    p1 : input complex\n    p2 : input complex\n    p3 : input complex\n    p4 : input complex\n  Return objects:\n    y : rank-1 array('D') with bounds (n)\n  def matvec(x,[n,m,p1,p2,p3,p4]): return y\n  Required arguments:\n    x : input rank-1 array('D') with bounds (n)\n  Optional arguments:\n    n : input int, optional\n    Default: len(x)\n    m : input int\n    p1 : input complex\n    p2 : input complex\n    p3 : input complex\n    p4 : input complex\n  Return objects:\n    y : rank-1 array('D') with bounds (m)\n  def matvec2(x,[n,m,p1,p2,p3,p4]): return y\n  Required arguments:\n    x : input rank-1 array('D') with bounds (n)\n  Optional arguments:\n    n : input int, optional\n    Default: len(x)\n    m : input int\n    p1 : input complex\n    p2 : input complex\n    p3 : input complex\n    p4 : input complex\n  Return objects:\n    y : rank-1 array('D') with bounds (m)\n"
    ...

def idz_estrank(eps, a, w, ra, m=..., n=...) -> typing.Any:
    "krank,ra = idz_estrank(eps,a,w,ra,[m,n])\n\nWrapper for ``idz_estrank``.\n\nParameters\n----------\neps : input float\na : input rank-2 array('D') with bounds (m,n)\nw : input rank-1 array('D') with bounds (17 * m + 70)\nra : input rank-1 array('D') with bounds (*)\n\nOther Parameters\n----------------\nm : input int, optional\n    Default: shape(a,0)\nn : input int, optional\n    Default: shape(a,1)\n\nReturns\n-------\nkrank : int\nra : rank-1 array('D') with bounds (*)\n"
    ...

def idz_findrank(eps, m, n, matveca, p1=..., p2=..., p3=..., p4=..., w=..., matveca_extra_args=...) -> typing.Any:
    "krank,ra,ier = idz_findrank(eps,m,n,matveca,[p1,p2,p3,p4,w,matveca_extra_args])\n\nWrapper for ``idz_findrank``.\n\nParameters\n----------\neps : input float\nm : input int\nn : input int\nmatveca : call-back function\n\nOther Parameters\n----------------\nmatveca_extra_args : input tuple, optional\n    Default: ()\np1 : input complex\np2 : input complex\np3 : input complex\np4 : input complex\nw : input rank-1 array('D') with bounds (m+2*n+1)\n\nReturns\n-------\nkrank : int\nra : rank-1 array('D') with bounds (2*n*min(m,n))\nier : int\n\nNotes\n-----\nCall-back functions::\n\n  def matveca(x,[m,n,p1,p2,p3,p4]): return y\n  Required arguments:\n    x : input rank-1 array('D') with bounds (m)\n  Optional arguments:\n    m : input int, optional\n    Default: len(x)\n    n : input int\n    p1 : input complex\n    p2 : input complex\n    p3 : input complex\n    p4 : input complex\n  Return objects:\n    y : rank-1 array('D') with bounds (n)\n"
    ...

def idz_frm(n, w, x, m=...) -> typing.Any:
    "y = idz_frm(n,w,x,[m])\n\nWrapper for ``idz_frm``.\n\nParameters\n----------\nn : input int\nw : input rank-1 array('D') with bounds (17 * m + 70)\nx : input rank-1 array('D') with bounds (m)\n\nOther Parameters\n----------------\nm : input int, optional\n    Default: len(x)\n\nReturns\n-------\ny : rank-1 array('D') with bounds (n)\n"
    ...

def idz_frmi(m) -> typing.Any:
    "n,w = idz_frmi(m)\n\nWrapper for ``idz_frmi``.\n\nParameters\n----------\nm : input int\n\nReturns\n-------\nn : int\nw : rank-1 array('D') with bounds (17 * m + 70)\n"
    ...

def idz_id2svd(b, list, proj, m=..., krank=..., n=..., w=...) -> typing.Any:
    "u,v,s,ier = idz_id2svd(b,list,proj,[m,krank,n,w])\n\nWrapper for ``idz_id2svd``.\n\nParameters\n----------\nb : input rank-2 array('D') with bounds (m,krank)\nlist : input rank-1 array('i') with bounds (n)\nproj : input rank-2 array('D') with bounds (krank,n-krank)\n\nOther Parameters\n----------------\nm : input int, optional\n    Default: shape(b,0)\nkrank : input int, optional\n    Default: shape(b,1)\nn : input int, optional\n    Default: len(list)\nw : input rank-1 array('D') with bounds ((krank+1)*(m+3*n+10)+9*pow(krank,2))\n\nReturns\n-------\nu : rank-2 array('D') with bounds (m,krank)\nv : rank-2 array('D') with bounds (n,krank)\ns : rank-1 array('d') with bounds (krank)\nier : int\n"
    ...

def idz_reconid(col, list, proj, m=..., krank=..., n=...) -> typing.Any:
    "approx = idz_reconid(col,list,proj,[m,krank,n])\n\nWrapper for ``idz_reconid``.\n\nParameters\n----------\ncol : input rank-2 array('D') with bounds (m,krank)\nlist : input rank-1 array('i') with bounds (n)\nproj : input rank-2 array('D') with bounds (krank,n-krank)\n\nOther Parameters\n----------------\nm : input int, optional\n    Default: shape(col,0)\nkrank : input int, optional\n    Default: shape(col,1)\nn : input int, optional\n    Default: len(list)\n\nReturns\n-------\napprox : rank-2 array('D') with bounds (m,n)\n"
    ...

def idz_reconint(list, proj, n=..., krank=...) -> typing.Any:
    "p = idz_reconint(list,proj,[n,krank])\n\nWrapper for ``idz_reconint``.\n\nParameters\n----------\nlist : input rank-1 array('i') with bounds (n)\nproj : input rank-2 array('D') with bounds (krank,n-krank)\n\nOther Parameters\n----------------\nn : input int, optional\n    Default: len(list)\nkrank : input int, optional\n    Default: shape(proj,0)\n\nReturns\n-------\np : rank-2 array('D') with bounds (krank,n)\n"
    ...

def idz_sfrm(l, n, w, x, m=...) -> typing.Any:
    "y = idz_sfrm(l,n,w,x,[m])\n\nWrapper for ``idz_sfrm``.\n\nParameters\n----------\nl : input int\nn : input int\nw : input rank-1 array('D') with bounds (27 * m + 90)\nx : input rank-1 array('D') with bounds (m)\n\nOther Parameters\n----------------\nm : input int, optional\n    Default: len(x)\n\nReturns\n-------\ny : rank-1 array('D') with bounds (l)\n"
    ...

def idz_sfrmi(l, m) -> typing.Any:
    "n,w = idz_sfrmi(l,m)\n\nWrapper for ``idz_sfrmi``.\n\nParameters\n----------\nl : input int\nm : input int\n\nReturns\n-------\nn : int\nw : rank-1 array('D') with bounds (27 * m + 90)\n"
    ...

def idz_snorm(m, n, matveca, matvec, its, p1a=..., p2a=..., p3a=..., p4a=..., p1=..., p2=..., p3=..., p4=..., u=..., matveca_extra_args=..., matvec_extra_args=...) -> typing.Any:
    "snorm,v = idz_snorm(m,n,matveca,matvec,its,[p1a,p2a,p3a,p4a,p1,p2,p3,p4,u,matveca_extra_args,matvec_extra_args])\n\nWrapper for ``idz_snorm``.\n\nParameters\n----------\nm : input int\nn : input int\nmatveca : call-back function\nmatvec : call-back function\nits : input int\n\nOther Parameters\n----------------\nmatveca_extra_args : input tuple, optional\n    Default: ()\np1a : input complex\np2a : input complex\np3a : input complex\np4a : input complex\nmatvec_extra_args : input tuple, optional\n    Default: ()\np1 : input complex\np2 : input complex\np3 : input complex\np4 : input complex\nu : input rank-1 array('D') with bounds (m)\n\nReturns\n-------\nsnorm : float\nv : rank-1 array('D') with bounds (n)\n\nNotes\n-----\nCall-back functions::\n\n  def matveca(x,[m,n,p1,p2,p3,p4]): return y\n  Required arguments:\n    x : input rank-1 array('D') with bounds (m)\n  Optional arguments:\n    m : input int, optional\n    Default: len(x)\n    n : input int\n    p1 : input complex\n    p2 : input complex\n    p3 : input complex\n    p4 : input complex\n  Return objects:\n    y : rank-1 array('D') with bounds (n)\n  def matvec(x,[n,m,p1,p2,p3,p4]): return y\n  Required arguments:\n    x : input rank-1 array('D') with bounds (n)\n  Optional arguments:\n    n : input int, optional\n    Default: len(x)\n    m : input int\n    p1 : input complex\n    p2 : input complex\n    p3 : input complex\n    p4 : input complex\n  Return objects:\n    y : rank-1 array('D') with bounds (m)\n"
    ...

def idzp_aid(eps, a, work, proj, m=..., n=...) -> typing.Any:
    "krank,list,proj = idzp_aid(eps,a,work,proj,[m,n])\n\nWrapper for ``idzp_aid``.\n\nParameters\n----------\neps : input float\na : input rank-2 array('D') with bounds (m,n)\nwork : input rank-1 array('D') with bounds (17 * m + 70)\nproj : input rank-1 array('D') with bounds (*)\n\nOther Parameters\n----------------\nm : input int, optional\n    Default: shape(a,0)\nn : input int, optional\n    Default: shape(a,1)\n\nReturns\n-------\nkrank : int\nlist : rank-1 array('i') with bounds (n)\nproj : rank-1 array('D') with bounds (*)\n"
    ...

def idzp_asvd(eps, a, winit, w, m=..., n=...) -> typing.Any:
    "krank,iu,iv,is,w,ier = idzp_asvd(eps,a,winit,w,[m,n])\n\nWrapper for ``idzp_asvd``.\n\nParameters\n----------\neps : input float\na : input rank-2 array('D') with bounds (m,n)\nwinit : input rank-1 array('D') with bounds (17 * m + 70)\nw : input rank-1 array('D') with bounds (*)\n\nOther Parameters\n----------------\nm : input int, optional\n    Default: shape(a,0)\nn : input int, optional\n    Default: shape(a,1)\n\nReturns\n-------\nkrank : int\niu : int\niv : int\nis : int\nw : rank-1 array('D') with bounds (*)\nier : int\n"
    ...

def idzp_id(eps, a, m=..., n=...) -> typing.Any:
    "krank,list,rnorms = idzp_id(eps,a,[m,n])\n\nWrapper for ``idzp_id``.\n\nParameters\n----------\neps : input float\na : input rank-2 array('D') with bounds (m,n)\n\nOther Parameters\n----------------\nm : input int, optional\n    Default: shape(a,0)\nn : input int, optional\n    Default: shape(a,1)\n\nReturns\n-------\nkrank : int\nlist : rank-1 array('i') with bounds (n)\nrnorms : rank-1 array('d') with bounds (n)\n"
    ...

def idzp_rid(eps, m, n, matveca, proj, p1=..., p2=..., p3=..., p4=..., matveca_extra_args=...) -> typing.Any:
    "krank,list,proj,ier = idzp_rid(eps,m,n,matveca,proj,[p1,p2,p3,p4,matveca_extra_args])\n\nWrapper for ``idzp_rid``.\n\nParameters\n----------\neps : input float\nm : input int\nn : input int\nmatveca : call-back function\nproj : input rank-1 array('D') with bounds (*)\n\nOther Parameters\n----------------\nmatveca_extra_args : input tuple, optional\n    Default: ()\np1 : input complex\np2 : input complex\np3 : input complex\np4 : input complex\n\nReturns\n-------\nkrank : int\nlist : rank-1 array('i') with bounds (n)\nproj : rank-1 array('D') with bounds (*)\nier : int\n\nNotes\n-----\nCall-back functions::\n\n  def matveca(x,[m,n,p1,p2,p3,p4]): return y\n  Required arguments:\n    x : input rank-1 array('D') with bounds (m)\n  Optional arguments:\n    m : input int, optional\n    Default: len(x)\n    n : input int\n    p1 : input complex\n    p2 : input complex\n    p3 : input complex\n    p4 : input complex\n  Return objects:\n    y : rank-1 array('D') with bounds (n)\n"
    ...

def idzp_rsvd(eps, m, n, matveca, matvec, p1a=..., p2a=..., p3a=..., p4a=..., p1=..., p2=..., p3=..., p4=..., matveca_extra_args=..., matvec_extra_args=...) -> typing.Any:
    "krank,iu,iv,is,w,ier = idzp_rsvd(eps,m,n,matveca,matvec,[p1a,p2a,p3a,p4a,p1,p2,p3,p4,matveca_extra_args,matvec_extra_args])\n\nWrapper for ``idzp_rsvd``.\n\nParameters\n----------\neps : input float\nm : input int\nn : input int\nmatveca : call-back function\nmatvec : call-back function\n\nOther Parameters\n----------------\nmatveca_extra_args : input tuple, optional\n    Default: ()\np1a : input complex\np2a : input complex\np3a : input complex\np4a : input complex\nmatvec_extra_args : input tuple, optional\n    Default: ()\np1 : input complex\np2 : input complex\np3 : input complex\np4 : input complex\n\nReturns\n-------\nkrank : int\niu : int\niv : int\nis : int\nw : rank-1 array('D') with bounds ((min(m,n)+1)*(3*m+5*n+11)+8*pow(min(m,n),2))\nier : int\n\nNotes\n-----\nCall-back functions::\n\n  def matveca(x,[m,n,p1,p2,p3,p4]): return y\n  Required arguments:\n    x : input rank-1 array('D') with bounds (m)\n  Optional arguments:\n    m : input int, optional\n    Default: len(x)\n    n : input int\n    p1 : input complex\n    p2 : input complex\n    p3 : input complex\n    p4 : input complex\n  Return objects:\n    y : rank-1 array('D') with bounds (n)\n  def matvec(x,[n,m,p1,p2,p3,p4]): return y\n  Required arguments:\n    x : input rank-1 array('D') with bounds (n)\n  Optional arguments:\n    n : input int, optional\n    Default: len(x)\n    m : input int\n    p1 : input complex\n    p2 : input complex\n    p3 : input complex\n    p4 : input complex\n  Return objects:\n    y : rank-1 array('D') with bounds (m)\n"
    ...

def idzp_svd(eps, a, m=..., n=...) -> typing.Any:
    "krank,iu,iv,is,w,ier = idzp_svd(eps,a,[m,n])\n\nWrapper for ``idzp_svd``.\n\nParameters\n----------\neps : input float\na : input rank-2 array('D') with bounds (m,n)\n\nOther Parameters\n----------------\nm : input int, optional\n    Default: shape(a,0)\nn : input int, optional\n    Default: shape(a,1)\n\nReturns\n-------\nkrank : int\niu : int\niv : int\nis : int\nw : rank-1 array('D') with bounds ((min(m,n)+1)*(m+2*n+9)+8*min(m,n)+6*pow(min(m,n),2))\nier : int\n"
    ...

def idzr_aid(a, krank, w, m=..., n=...) -> typing.Any:
    "list,proj = idzr_aid(a,krank,w,[m,n])\n\nWrapper for ``idzr_aid``.\n\nParameters\n----------\na : input rank-2 array('D') with bounds (m,n)\nkrank : input int\nw : input rank-1 array('D') with bounds ((2*krank+17)*n+21*m+80)\n\nOther Parameters\n----------------\nm : input int, optional\n    Default: shape(a,0)\nn : input int, optional\n    Default: shape(a,1)\n\nReturns\n-------\nlist : rank-1 array('i') with bounds (n)\nproj : rank-1 array('D') with bounds (max(krank*(n-krank),1))\n"
    ...

def idzr_aidi(m, n, krank) -> typing.Any:
    "w = idzr_aidi(m,n,krank)\n\nWrapper for ``idzr_aidi``.\n\nParameters\n----------\nm : input int\nn : input int\nkrank : input int\n\nReturns\n-------\nw : rank-1 array('D') with bounds ((2*krank+17)*n+21*m+80)\n"
    ...

def idzr_asvd(a, krank, w, m=..., n=...) -> typing.Any:
    "u,v,s,ier = idzr_asvd(a,krank,w,[m,n])\n\nWrapper for ``idzr_asvd``.\n\nParameters\n----------\na : input rank-2 array('D') with bounds (m,n)\nkrank : input int\nw : input rank-1 array('D') with bounds ((2*krank+22)*m+(6*krank+21)*n+8*pow(krank,2)+10*krank+90)\n\nOther Parameters\n----------------\nm : input int, optional\n    Default: shape(a,0)\nn : input int, optional\n    Default: shape(a,1)\n\nReturns\n-------\nu : rank-2 array('D') with bounds (m,krank)\nv : rank-2 array('D') with bounds (n,krank)\ns : rank-1 array('d') with bounds (krank)\nier : int\n"
    ...

def idzr_id(a, krank, m=..., n=...) -> typing.Any:
    "list,rnorms = idzr_id(a,krank,[m,n])\n\nWrapper for ``idzr_id``.\n\nParameters\n----------\na : input rank-2 array('D') with bounds (m,n)\nkrank : input int\n\nOther Parameters\n----------------\nm : input int, optional\n    Default: shape(a,0)\nn : input int, optional\n    Default: shape(a,1)\n\nReturns\n-------\nlist : rank-1 array('i') with bounds (n)\nrnorms : rank-1 array('d') with bounds (n)\n"
    ...

def idzr_rid(m, n, matveca, krank, p1=..., p2=..., p3=..., p4=..., matveca_extra_args=...) -> typing.Any:
    "list,proj = idzr_rid(m,n,matveca,krank,[p1,p2,p3,p4,matveca_extra_args])\n\nWrapper for ``idzr_rid``.\n\nParameters\n----------\nm : input int\nn : input int\nmatveca : call-back function\nkrank : input int\n\nOther Parameters\n----------------\nmatveca_extra_args : input tuple, optional\n    Default: ()\np1 : input complex\np2 : input complex\np3 : input complex\np4 : input complex\n\nReturns\n-------\nlist : rank-1 array('i') with bounds (n)\nproj : rank-1 array('D') with bounds (m+(krank+3)*n)\n\nNotes\n-----\nCall-back functions::\n\n  def matveca(x,[m,n,p1,p2,p3,p4]): return y\n  Required arguments:\n    x : input rank-1 array('D') with bounds (m)\n  Optional arguments:\n    m : input int, optional\n    Default: len(x)\n    n : input int\n    p1 : input complex\n    p2 : input complex\n    p3 : input complex\n    p4 : input complex\n  Return objects:\n    y : rank-1 array('D') with bounds (n)\n"
    ...

def idzr_rsvd(m, n, matveca, matvec, krank, p1a=..., p2a=..., p3a=..., p4a=..., p1=..., p2=..., p3=..., p4=..., w=..., matveca_extra_args=..., matvec_extra_args=...) -> typing.Any:
    "u,v,s,ier = idzr_rsvd(m,n,matveca,matvec,krank,[p1a,p2a,p3a,p4a,p1,p2,p3,p4,w,matveca_extra_args,matvec_extra_args])\n\nWrapper for ``idzr_rsvd``.\n\nParameters\n----------\nm : input int\nn : input int\nmatveca : call-back function\nmatvec : call-back function\nkrank : input int\n\nOther Parameters\n----------------\nmatveca_extra_args : input tuple, optional\n    Default: ()\np1a : input complex\np2a : input complex\np3a : input complex\np4a : input complex\nmatvec_extra_args : input tuple, optional\n    Default: ()\np1 : input complex\np2 : input complex\np3 : input complex\np4 : input complex\nw : input rank-1 array('D') with bounds ((krank+1)*(2*m+4*n+10)+8*pow(krank,2))\n\nReturns\n-------\nu : rank-2 array('D') with bounds (m,krank)\nv : rank-2 array('D') with bounds (n,krank)\ns : rank-1 array('d') with bounds (krank)\nier : int\n\nNotes\n-----\nCall-back functions::\n\n  def matveca(x,[m,n,p1,p2,p3,p4]): return y\n  Required arguments:\n    x : input rank-1 array('D') with bounds (m)\n  Optional arguments:\n    m : input int, optional\n    Default: len(x)\n    n : input int\n    p1 : input complex\n    p2 : input complex\n    p3 : input complex\n    p4 : input complex\n  Return objects:\n    y : rank-1 array('D') with bounds (n)\n  def matvec(x,[n,m,p1,p2,p3,p4]): return y\n  Required arguments:\n    x : input rank-1 array('D') with bounds (n)\n  Optional arguments:\n    n : input int, optional\n    Default: len(x)\n    m : input int\n    p1 : input complex\n    p2 : input complex\n    p3 : input complex\n    p4 : input complex\n  Return objects:\n    y : rank-1 array('D') with bounds (m)\n"
    ...

def idzr_svd(a, krank, m=..., n=..., r=...) -> typing.Any:
    "u,v,s,ier = idzr_svd(a,krank,[m,n,r])\n\nWrapper for ``idzr_svd``.\n\nParameters\n----------\na : input rank-2 array('D') with bounds (m,n)\nkrank : input int\n\nOther Parameters\n----------------\nm : input int, optional\n    Default: shape(a,0)\nn : input int, optional\n    Default: shape(a,1)\nr : input rank-1 array('D') with bounds ((krank+2)*n+8*min(m,n)+6*pow(krank,2)+8*krank)\n\nReturns\n-------\nu : rank-2 array('D') with bounds (m,krank)\nv : rank-2 array('D') with bounds (n,krank)\ns : rank-1 array('d') with bounds (krank)\nier : int\n"
    ...

def __getattr__(name) -> typing.Any:
    ...




from typing import Mapping
import math

from ...classes.graph import Graph
from ...utils import not_implemented_for

__all__ = ["eigenvector_centrality", "eigenvector_centrality_numpy"]

def eigenvector_centrality(
    G: Graph, max_iter=100, tol=1.0e-6, nstart=None, weight=None
) -> Mapping: ...
def eigenvector_centrality_numpy(
    G: Graph, weight=None, max_iter=50, tol=0
) -> Mapping: ...



from .generic import (
    shortest_path as shortest_path,
    all_shortest_paths as all_shortest_paths,
    shortest_path_length as shortest_path_length,
    average_shortest_path_length as average_shortest_path_length,
    has_path as has_path,
)
from .unweighted import (
    bidirectional_shortest_path as bidirectional_shortest_path,
    single_source_shortest_path as single_source_shortest_path,
    single_source_shortest_path_length as single_source_shortest_path_length,
    single_target_shortest_path as single_target_shortest_path,
    single_target_shortest_path_length as single_target_shortest_path_length,
    all_pairs_shortest_path as all_pairs_shortest_path,
    all_pairs_shortest_path_length as all_pairs_shortest_path_length,
    predecessor as predecessor,
)
from .weighted import (
    dijkstra_path as dijkstra_path,
    dijkstra_path_length as dijkstra_path_length,
    bidirectional_dijkstra as bidirectional_dijkstra,
    single_source_dijkstra as single_source_dijkstra,
    single_source_dijkstra_path as single_source_dijkstra_path,
    single_source_dijkstra_path_length as single_source_dijkstra_path_length,
    multi_source_dijkstra as multi_source_dijkstra,
    multi_source_dijkstra_path as multi_source_dijkstra_path,
    multi_source_dijkstra_path_length as multi_source_dijkstra_path_length,
    all_pairs_dijkstra as all_pairs_dijkstra,
    all_pairs_dijkstra_path as all_pairs_dijkstra_path,
    all_pairs_dijkstra_path_length as all_pairs_dijkstra_path_length,
    dijkstra_predecessor_and_distance as dijkstra_predecessor_and_distance,
    bellman_ford_path as bellman_ford_path,
    bellman_ford_path_length as bellman_ford_path_length,
    single_source_bellman_ford as single_source_bellman_ford,
    single_source_bellman_ford_path as single_source_bellman_ford_path,
    single_source_bellman_ford_path_length as single_source_bellman_ford_path_length,
    all_pairs_bellman_ford_path as all_pairs_bellman_ford_path,
    all_pairs_bellman_ford_path_length as all_pairs_bellman_ford_path_length,
    bellman_ford_predecessor_and_distance as bellman_ford_predecessor_and_distance,
    negative_edge_cycle as negative_edge_cycle,
    find_negative_cycle as find_negative_cycle,
    goldberg_radzik as goldberg_radzik,
    johnson as johnson,
)
from .astar import astar_path as astar_path, astar_path_length as astar_path_length
from .dense import (
    floyd_warshall as floyd_warshall,
    floyd_warshall_predecessor_and_distance as floyd_warshall_predecessor_and_distance,
    reconstruct_path as reconstruct_path,
    floyd_warshall_numpy as floyd_warshall_numpy,
)



import matplotlib.dates as dates
from matplotlib.ticker import (
    Formatter,
    Locator,
)
import matplotlib.units as units

HOURS_PER_DAY: float = ...
MIN_PER_HOUR: float = ...
SEC_PER_MIN: float = ...
SEC_PER_HOUR: float = ...
SEC_PER_DAY: float = ...
MUSEC_PER_DAY: float = ...

def get_pairs(): ...
def register_pandas_matplotlib_converters(func): ...
def pandas_converters() -> None: ...
def register() -> None: ...
def deregister() -> None: ...
def time2num(d): ...

class TimeConverter(units.ConversionInterface):
    @staticmethod
    def convert(value, unit, axis): ...
    @staticmethod
    def axisinfo(unit, axis): ...
    @staticmethod
    def default_units(x, axis): ...

class TimeFormatter(Formatter):
    locs = ...
    def __init__(self, locs) -> None: ...
    def __call__(self, x, pos: int = ...): ...

class PeriodConverter(dates.DateConverter):
    @staticmethod
    def convert(values, units, axis): ...

def get_datevalue(date, freq): ...

class DatetimeConverter(dates.DateConverter):
    @staticmethod
    def convert(values, unit, axis): ...
    @staticmethod
    def axisinfo(unit, axis): ...

class PandasAutoDateFormatter(dates.AutoDateFormatter):
    def __init__(self, locator, tz=..., defaultfmt: str = ...) -> None: ...

class PandasAutoDateLocator(dates.AutoDateLocator):
    def get_locator(self, dmin, dmax): ...

class MilliSecondLocator(dates.DateLocator):
    UNIT = ...
    def __init__(self, tz) -> None: ...
    @staticmethod
    def get_unit_generic(freq): ...
    def __call__(self): ...
    def autoscale(self): ...

def period_break(dates, period): ...
def has_level_label(label_flags, vmin): ...
def get_finder(freq): ...

class TimeSeries_DateLocator(Locator):
    freq = ...
    base = ...
    isminor = ...
    isdynamic = ...
    offset: int = ...
    plot_obj = ...
    finder = ...
    def __init__(
        self,
        freq,
        minor_locator: bool = ...,
        dynamic_mode: bool = ...,
        base: int = ...,
        quarter: int = ...,
        month: int = ...,
        day: int = ...,
        plot_obj=...,
    ) -> None: ...
    def __call__(self): ...
    def autoscale(self): ...

class TimeSeries_DateFormatter(Formatter):
    format = ...
    freq = ...
    locs = ...
    formatdict = ...
    isminor = ...
    isdynamic = ...
    offset: int = ...
    plot_obj = ...
    finder = ...
    def __init__(
        self, freq, minor_locator: bool = ..., dynamic_mode: bool = ..., plot_obj=...
    ) -> None: ...
    def set_locs(self, locs) -> None: ...
    def __call__(self, x, pos: int = ...): ...

class TimeSeries_TimedeltaFormatter(Formatter):
    @staticmethod
    def format_timedelta_ticks(x, pos, n_decimals): ...
    def __call__(self, x, pos: int = ...): ...



# -*- coding: utf-8 -*-
# Copyright (c) Vispy Development Team. All Rights Reserved.
# Distributed under the (new) BSD License. See LICENSE.txt for more info.

from ..util.event import Event

class SceneMouseEvent(Event):
    def __init__(self, event, visual): ...
    @property
    def visual(self): ...
    @visual.setter
    def visual(self, v): ...
    @property
    def pos(self): ...
    @property
    def last_event(self): ...
    @property
    def press_event(self): ...
    @property
    def button(self): ...
    @property
    def buttons(self): ...
    @property
    def delta(self): ...
    def copy(self): ...



from typing import ClassVar, TypeVar
from scipy import optimize as optimize
from ._base import LinearModel
from numpy import ndarray
from ..utils._param_validation import Interval as Interval
from ..utils.extmath import safe_sparse_dot as safe_sparse_dot
from numbers import Integral as Integral, Real as Real
from ..base import BaseEstimator, RegressorMixin
from .._typing import Float, Int, MatrixLike, ArrayLike
from ..utils import axis0_safe_slice as axis0_safe_slice

HuberRegressor_Self = TypeVar("HuberRegressor_Self", bound="HuberRegressor")

# Authors: Manoj Kumar mks542@nyu.edu
# License: BSD 3 clause

import numpy as np


class HuberRegressor(LinearModel, RegressorMixin, BaseEstimator):
    outliers_: ndarray = ...
    n_iter_: int = ...
    feature_names_in_: ndarray = ...
    n_features_in_: int = ...
    scale_: float = ...
    intercept_: float = ...
    coef_: ndarray = ...

    _parameter_constraints: ClassVar[dict] = ...

    def __init__(
        self,
        *,
        epsilon: Float = 1.35,
        max_iter: Int = 100,
        alpha: Float = 0.0001,
        warm_start: bool = False,
        fit_intercept: bool = True,
        tol: Float = 1e-05,
    ) -> None:
        ...

    def fit(
        self: HuberRegressor_Self,
        X: MatrixLike,
        y: ArrayLike,
        sample_weight: None | ArrayLike = None,
    ) -> HuberRegressor_Self:
        ...




# This file is generated by docs2stub. These types are intended
# to simplify the stubs generated by docs2stub. They are not
# intended to be used directly by other users.

import decimal
import io
import numpy.typing
import numpy as np
import pandas as pd
from .base import BaseEstimator, ClassifierMixin, RegressorMixin
from scipy.sparse import spmatrix



Decimal = decimal.Decimal
PythonScalar = str | int | float | bool

ArrayLike = numpy.typing.ArrayLike
MatrixLike = np.ndarray | pd.DataFrame | spmatrix
FileLike = io.IOBase
PathLike = str
Int = int | np.int8 | np.int16 | np.int32 | np.int64
Float = float | np.float16 | np.float32 | np.float64

PandasScalar = pd.Period | pd.Timestamp | pd.Timedelta | pd.Interval
Scalar = PythonScalar | PandasScalar

Estimator = BaseEstimator
Classifier = ClassifierMixin
Regressor = RegressorMixin

Color = tuple[float, float, float] | str

        


from typing import Any, ClassVar, TypeVar
from numpy.random import RandomState
from collections import defaultdict as defaultdict
from numpy import ndarray
from ..utils._param_validation import Interval as Interval
from numbers import Integral as Integral, Real as Real
from .._config import config_context as config_context
from ..neighbors import NearestNeighbors as NearestNeighbors
from ..base import BaseEstimator, ClusterMixin
from ..metrics.pairwise import pairwise_distances_argmin as pairwise_distances_argmin
from ..utils.parallel import delayed as delayed, Parallel as Parallel
from .._typing import MatrixLike, Float, Int
from ..utils import (
    check_random_state as check_random_state,
    gen_batches as gen_batches,
    check_array as check_array,
)
from ..utils.validation import check_is_fitted as check_is_fitted

MeanShift_Self = TypeVar("MeanShift_Self", bound="MeanShift")


# Authors: Conrad Lee <conradlee@gmail.com>
#          Alexandre Gramfort <alexandre.gramfort@inria.fr>
#          Gael Varoquaux <gael.varoquaux@normalesup.org>
#          Martino Sorbaro <martino.sorbaro@ed.ac.uk>

import numpy as np
import warnings


def estimate_bandwidth(
    X: MatrixLike,
    *,
    quantile: Float = 0.3,
    n_samples: None | Int = None,
    random_state: RandomState | Int = 0,
    n_jobs: None | Int = None,
) -> Float:
    ...


def mean_shift(
    X: MatrixLike,
    *,
    bandwidth: None | Float = None,
    seeds: None | MatrixLike = None,
    bin_seeding: bool = False,
    min_bin_freq: Int = 1,
    cluster_all: bool = True,
    max_iter: Int = 300,
    n_jobs: None | Int = None,
) -> tuple[ndarray, ndarray]:
    ...


def get_bin_seeds(X: MatrixLike, bin_size: Float, min_bin_freq: Int = 1) -> ndarray:
    ...


class MeanShift(ClusterMixin, BaseEstimator):
    feature_names_in_: ndarray = ...
    n_features_in_: int = ...
    n_iter_: int = ...
    labels_: ndarray = ...
    cluster_centers_: ndarray = ...

    _parameter_constraints: ClassVar[dict] = ...

    def __init__(
        self,
        *,
        bandwidth: None | Float = None,
        seeds: None | MatrixLike = None,
        bin_seeding: bool = False,
        min_bin_freq: Int = 1,
        cluster_all: bool = True,
        n_jobs: None | Int = None,
        max_iter: Int = 300,
    ) -> None:
        ...

    def fit(self: MeanShift_Self, X: MatrixLike, y: Any = None) -> MeanShift_Self:
        ...

    def predict(self, X: MatrixLike) -> ndarray:
        ...



from django.contrib.gis.db.backends.base.features import (
    BaseSpatialFeatures as BaseSpatialFeatures,
)
from django.db.backends.postgresql.features import (
    DatabaseFeatures as Psycopg2DatabaseFeatures,
)

class DatabaseFeatures(BaseSpatialFeatures, Psycopg2DatabaseFeatures):
    supports_3d_storage: bool = ...
    supports_3d_functions: bool = ...
    supports_left_right_lookups: bool = ...
    supports_raster: bool = ...
    supports_empty_geometries: bool = ...



from typing import Any, Callable, ClassVar, Literal, TypeVar
from numpy.random import RandomState
from scipy import sparse as sparse
from scipy.sparse._coo import coo_matrix
from ..utils.fixes import lobpcg
from scipy.sparse.csgraph import (
    connected_components as connected_components,
    laplacian as csgraph_laplacian,
)
from pyamg import smoothed_aggregation_solver as smoothed_aggregation_solver
from ..metrics.pairwise import rbf_kernel as rbf_kernel
from scipy.sparse.linalg import eigsh as eigsh
from numpy import ndarray
from ..utils._param_validation import Interval as Interval, StrOptions as StrOptions
from numbers import Integral as Integral, Real as Real
from ..base import BaseEstimator
from ..utils import (
    check_array as check_array,
    check_random_state as check_random_state,
    check_symmetric as check_symmetric,
)
from scipy.linalg import eigh as eigh
from ..neighbors import (
    kneighbors_graph as kneighbors_graph,
    NearestNeighbors as NearestNeighbors,
)
from .._typing import MatrixLike, Int, Float, ArrayLike

SpectralEmbedding_Self = TypeVar("SpectralEmbedding_Self", bound="SpectralEmbedding")

import warnings

import numpy as np


def spectral_embedding(
    adjacency: coo_matrix | MatrixLike,
    *,
    n_components: Int = 8,
    eigen_solver: None | Literal["arpack", "lobpcg", "amg"] = None,
    random_state: RandomState | None | Int = None,
    eigen_tol: str | Float = "auto",
    norm_laplacian: bool = True,
    drop_first: bool = True,
) -> ndarray:
    ...


class SpectralEmbedding(BaseEstimator):
    n_neighbors_: int = ...
    feature_names_in_: ndarray = ...
    n_features_in_: int = ...
    affinity_matrix_: ndarray = ...
    embedding_: ndarray = ...

    _parameter_constraints: ClassVar[dict] = ...

    def __init__(
        self,
        n_components: Int = 2,
        *,
        affinity: Literal[
            "nearest_neighbors",
            "rbf",
            "precomputed",
            "precomputed_nearest_neighbors",
            "nearest_neighbors",
        ]
        | Callable = "nearest_neighbors",
        gamma: None | Float = None,
        random_state: RandomState | None | Int = None,
        eigen_solver: None | Literal["arpack", "lobpcg", "amg"] = None,
        eigen_tol: str | Float = "auto",
        n_neighbors: None | Int = None,
        n_jobs: None | Int = None,
    ) -> None:
        ...

    def fit(
        self: SpectralEmbedding_Self, X: MatrixLike | ArrayLike, y: Any = None
    ) -> SpectralEmbedding_Self:
        ...

    def fit_transform(self, X: MatrixLike | ArrayLike, y: Any = None) -> ndarray:
        ...



# Python: 3.8.2 (tags/v3.8.2:7b3ab59, Feb 25 2020, 23:03:10) [MSC v.1916 64 bit (AMD64)]
# Library: scipy, version: 1.6.2
# Module: scipy.optimize._highs._highs_wrapper, version: unspecified
import typing
import builtins as _mod_builtins
import scipy.optimize.optimize as _mod_scipy_optimize_optimize

OptimizeWarning = _mod_scipy_optimize_optimize.OptimizeWarning
__doc__: typing.Any
__file__: str
__name__: str
__package__: str
def __pyx_unpickle_Enum() -> typing.Any:
    ...

__test__: dict
def _highs_wrapper() -> typing.Any:
    "Solve linear programs using HiGHS [1]_.\n\n    Assume problems of the form:\n\n        MIN c.T @ x\n        s.t. lhs <= A @ x <= rhs\n             lb <= x <= ub\n\n    Parameters\n    ----------\n    c : 1-D array, (n,)\n        Array of objective value coefficients.\n    astart : 1-D array\n        CSC format index array.\n    aindex : 1-D array\n        CSC format index array.\n    avalue : 1-D array\n        Data array of the matrix.\n    lhs : 1-D array (or None), (m,)\n        Array of left hand side values of the inequality constraints.\n        If ``lhs=None``, then an array of ``-inf`` is assumed.\n    rhs : 1-D array, (m,)\n        Array of right hand side values of the inequality constraints.\n    lb : 1-D array (or None), (n,)\n        Lower bounds on solution variables x.  If ``lb=None``, then an\n        array of all `0` is assumed.\n    ub : 1-D array (or None), (n,)\n        Upper bounds on solution variables x.  If ``ub=None``, then an\n        array of ``inf`` is assumed.\n    options : dict\n        A dictionary of solver options with the following fields:\n\n            - allowed_simplex_cost_scale_factor : int\n                Undocumented advanced option.\n\n            - allowed_simplex_matrix_scale_factor : int\n                Undocumented advanced option.\n\n            - dual_feasibility_tolerance : double\n                Dual feasibility tolerance for simplex.\n                ``min(dual_feasibility_tolerance,\n                primal_feasibility_tolerance)`` will be used for\n                ipm feasibility tolerance.\n\n            - dual_objective_value_upper_bound : double\n                Upper bound on objective value for dual simplex:\n                algorithm terminates if reached\n\n            - dual_simplex_cleanup_strategy : int\n                Undocumented advanced option.\n\n            - dual_simplex_cost_perturbation_multiplier : double\n                Undocumented advanced option.\n\n            - dual_steepest_edge_weight_log_error_threshhold : double\n                Undocumented advanced option.\n\n            - infinite_bound : double\n                Limit on abs(constraint bound): values larger than\n                this will be treated as infinite\n\n            - infinite_cost : double\n                Limit on cost coefficient: values larger than this\n                will be treated as infinite.\n\n            - ipm_iteration_limit : int\n                Iteration limit for interior-point solver.\n\n            - ipm_optimality_tolerance : double\n                Optimality tolerance for IPM.\n\n            - keep_n_rows : int {-1, 0, 1}\n                Undocumented advanced option.\n\n                    - ``-1``: ``KEEP_N_ROWS_DELETE_ROWS``\n                    - ``0``: ``KEEP_N_ROWS_DELETE_ENTRIES``\n                    - ``1``: ``KEEP_N_ROWS_KEEP_ROWS``\n\n            - large_matrix_value : double\n                Upper limit on abs(matrix entries): values larger than\n                this will be treated as infinite\n\n            - less_infeasible_DSE_check : bool\n                Undocumented advanced option.\n\n            - less_infeasible_DSE_choose_row : bool\n                Undocumented advanced option.\n\n            - max_threads : int\n                Maximum number of threads in parallel execution.\n\n            - message_level : int {0, 1, 2, 4, 7}\n                Verbosity level, corresponds to:\n\n                    - ``0``: ``ML_NONE``\n                        All messaging to stdout is supressed.\n\n                    - ``1``: ``ML_VERBOSE``\n                        Includes a once-per-iteration report on simplex/ipm\n                        progress and information about each nonzero row and\n                        column.\n\n                    - ``2``: ``ML_DETAILED``\n                        Includes technical information about progress and\n                        events in applying the simplex method.\n\n                    - ``4``: ``ML_MINIMAL``\n                        Once-per-solve information about progress as well as a\n                        once-per-basis-matrix-reinversion report on progress in\n                        simplex or a once-per-iteration report on progress in IPX.\n\n                ``message_level`` behaves like a bitmask, i.e., any\n                combination of levels is possible using the bit-or\n                operator.\n\n            - min_threads : int\n                Minimum number of threads in parallel execution.\n\n            - mps_parser_type_free : bool\n                Use free format MPS parsing.\n\n            - parallel : bool\n                Run the solver in serial (False) or parallel (True).\n\n            - presolve : bool\n                Run the presolve or not (or if ``None``, then choose).\n\n            - primal_feasibility_tolerance : double\n                Primal feasibility tolerance.\n                ``min(dual_feasibility_tolerance,\n                primal_feasibility_tolerance)`` will be used for\n                ipm feasibility tolerance.\n\n            - run_as_hsol : bool\n                Undocumented advanced option.\n\n            - run_crossover : bool\n                Advanced option. Toggles running the crossover routine\n                for IPX.\n\n            - sense : int {1, -1}\n                ``sense=1`` corresponds to the MIN problem, ``sense=-1``\n                corresponds to the MAX problem. TODO: NOT IMPLEMENTED\n\n            - simplex_crash_strategy : int {0, 1, 2, 3, 4, 5, 6, 7, 8, 9}\n                Strategy for simplex crash: off / LTSSF / Bixby (0/1/2).\n                Default is ``0``.  Corresponds to the following:\n\n                    - ``0``: ``SIMPLEX_CRASH_STRATEGY_OFF``\n                    - ``1``: ``SIMPLEX_CRASH_STRATEGY_LTSSF_K``\n                    - ``2``: ``SIMPLEX_CRASH_STRATEGY_BIXBY``\n                    - ``3``: ``SIMPLEX_CRASH_STRATEGY_LTSSF_PRI``\n                    - ``4``: ``SIMPLEX_CRASH_STRATEGY_LTSF_K``\n                    - ``5``: ``SIMPLEX_CRASH_STRATEGY_LTSF_PRI``\n                    - ``6``: ``SIMPLEX_CRASH_STRATEGY_LTSF``\n                    - ``7``: ``SIMPLEX_CRASH_STRATEGY_BIXBY_NO_NONZERO_COL_COSTS``\n                    - ``8``: ``SIMPLEX_CRASH_STRATEGY_BASIC``\n                    - ``9``: ``SIMPLE_CRASH_STRATEGY_TEST_SING``\n\n            - simplex_dualise_strategy : int\n                Undocumented advanced option.\n\n            - simplex_dual_edge_weight_strategy : int {0, 1, 2, 3, 4}\n                Strategy for simplex dual edge weights:\n                Dantzig / Devex / Steepest Edge. Corresponds\n                to the following:\n\n                    - ``0``: ``SIMPLEX_DUAL_EDGE_WEIGHT_STRATEGY_DANTZIG``\n                    - ``1``: ``SIMPLEX_DUAL_EDGE_WEIGHT_STRATEGY_DEVEX``\n                    - ``2``: ``SIMPLEX_DUAL_EDGE_WEIGHT_STRATEGY_STEEPEST_EDGE_TO_DEVEX_SWITCH``\n                    - ``3``: ``SIMPLEX_DUAL_EDGE_WEIGHT_STRATEGY_STEEPEST_EDGE``\n                    - ``4``: ``SIMPLEX_DUAL_EDGE_WEIGHT_STRATEGY_STEEPEST_EDGE_UNIT_INITIAL``\n\n            - simplex_initial_condition_check : bool\n                Undocumented advanced option.\n\n            - simplex_initial_condition_tolerance : double\n                Undocumented advanced option.\n\n            - simplex_iteration_limit : int\n                Iteration limit for simplex solver.\n\n            - simplex_permute_strategy : int\n                Undocumented advanced option.\n\n            - simplex_price_strategy : int\n                Undocumented advanced option.\n\n            - simplex_primal_edge_weight_strategy : int {0, 1}\n                Strategy for simplex primal edge weights:\n                Dantzig / Devex.  Corresponds to the following:\n\n                    - ``0``: ``SIMPLEX_PRIMAL_EDGE_WEIGHT_STRATEGY_DANTZIG``\n                    - ``1``: ``SIMPLEX_PRIMAL_EDGE_WEIGHT_STRATEGY_DEVEX``\n\n            - simplex_scale_strategy : int {0, 1, 2, 3, 4, 5}\n                Strategy for scaling before simplex solver:\n                off / on (0/1)\n\n                    - ``0``:  ``SIMPLEX_SCALE_STRATEGY_OFF``\n                    - ``1``: ``SIMPLEX_SCALE_STRATEGY_HIGHS``\n                    - ``2``: ``SIMPLEX_SCALE_STRATEGY_HIGHS_FORCED``\n                    - ``3``: ``SIMPLEX_SCALE_STRATEGY_HIGHS_015``\n                    - ``4``: ``SIMPLEX_SCALE_STRATEGY_HIGHS_0157``\n                    - ``5``: ``SIMPLEX_SCALE_STRATEGY_HSOL``\n\n            - simplex_strategy : int {0, 1, 2, 3, 4}\n                Strategy for simplex solver. Default: 1. Corresponds\n                to the following:\n\n                    - ``0``: ``SIMPLEX_STRATEGY_MIN``\n                    - ``1``: ``SIMPLEX_STRATEGY_DUAL``\n                    - ``2``: ``SIMPLEX_STRATEGY_DUAL_TASKS``\n                    - ``3``: ``SIMPLEX_STRATEGY_DUAL_MULTI``\n                    - ``4``: ``SIMPLEX_STRATEGY_PRIMAL``\n\n            - simplex_update_limit : int\n                Limit on the number of simplex UPDATE operations.\n\n            - small_matrix_value : double\n                Lower limit on abs(matrix entries): values smaller\n                than this will be treated as zero.\n\n            - solution_file : str\n                Solution file\n\n            - solver : str {'simplex', 'ipm'}\n                Choose which solver to use.  If ``solver='simplex'``\n                and ``parallel=True`` then PAMI will be used.\n\n            - time_limit : double\n                Max number of seconds to run the solver for.\n\n            - use_original_HFactor_logic : bool\n                Undocumented advanced option.\n\n            - write_solution_to_file : bool\n                Write the primal and dual solution to a file\n\n            - write_solution_pretty : bool\n                Write the primal and dual solution in a pretty\n                (human-readable) format\n\n        See [2]_ for a list of all non-advanced options.\n\n    Returns\n    -------\n    res : dict\n\n        If model_status is one of OPTIMAL,\n        REACHED_DUAL_OBJECTIVE_VALUE_UPPER_BOUND, REACHED_TIME_LIMIT,\n        REACHED_ITERATION_LIMIT:\n\n            - ``status`` : int\n                Model status code.\n\n            - ``message`` : str\n                Message corresponding to model status code.\n\n            - ``x`` : list\n                Solution variables.\n\n            - ``slack`` : list\n                Slack variables.\n\n            - ``lambda`` : list\n                Lagrange multipliers assoicated with the constraints\n                Ax = b.\n\n            - ``s`` : list\n                Lagrange multipliers associated with the constraints\n                x >= 0.\n\n            - ``fun``\n                Final objective value.\n\n            - ``simplex_nit`` : int\n                Number of iterations accomplished by the simplex\n                solver.\n\n            - ``ipm_nit`` : int\n                Number of iterations accomplished by the interior-\n                point solver.\n\n        If model_status is not one of the above:\n\n            - ``status`` : int\n                Model status code.\n\n            - ``message`` : str\n                Message corresponding to model status code.\n\n    Notes\n    -----\n    If ``options['write_solution_to_file']`` is ``True`` but\n    ``options['solution_file']`` is unset or ``''``, then the solution\n    will be printed to ``stdout``.\n\n    If any iteration limit is reached, no solution will be\n    available.\n\n    ``OptimizeWarning`` will be raised if any option value set by\n    the user is found to be incorrect.\n\n    References\n    ----------\n    .. [1] https://www.maths.ed.ac.uk/hall/HiGHS\n    .. [2] https://www.maths.ed.ac.uk/hall/HiGHS/HighsOptions.html\n    "
    ...

def warn(message, category, stacklevel, source) -> typing.Any:
    'Issue a warning, or maybe ignore it or raise an exception.'
    ...

def __getattr__(name) -> typing.Any:
    ...




from typing import IO

from pandas.io.formats.format import (
    DataFrameFormatter as DataFrameFormatter,
    TableFormatter as TableFormatter,
)

class LatexFormatter(TableFormatter):
    fmt = ...
    frame = ...
    bold_rows = ...
    column_format = ...
    longtable = ...
    multicolumn = ...
    multicolumn_format = ...
    multirow = ...
    caption = ...
    label = ...
    escape = ...
    def __init__(
        self,
        formatter: DataFrameFormatter,
        column_format: str | None = ...,
        longtable: bool = ...,
        multicolumn: bool = ...,
        multicolumn_format: str | None = ...,
        multirow: bool = ...,
        caption: str | None = ...,
        label: str | None = ...,
    ) -> None: ...
    clinebuf = ...
    def write_result(self, buf: IO[str]) -> None: ...



from numpy.typing import NDArray
import numpy as np
import functools
from scipy import ndimage as ndi
from .._shared.utils import warn, remove_arg
from .footprints import _default_footprint

# Our function names don't exactly correspond to ndimages.
# This dictionary translates from our names to scipy's.
funcs = ...
skimage2ndimage: dict = ...

# These function names are the same in ndimage.
funcs = ...

def default_footprint(func): ...
def _check_dtype_supported(ar): ...
@remove_arg(
    "in_place", changed_version="1.0", help_msg="Please use out argument instead."
)
def remove_small_objects(
    ar, min_size=64, connectivity=1, in_place=False, *, out: NDArray | None = None
): ...
@remove_arg(
    "in_place", changed_version="1.0", help_msg="Please use out argument instead."
)
def remove_small_holes(
    ar, area_threshold=64, connectivity=1, in_place=False, *, out: NDArray | None = None
): ...



from ..gloo.framebuffer import RenderBuffer
from typing import Literal
from numpy.typing import ArrayLike

# -*- coding: utf-8 -*-
# -----------------------------------------------------------------------------
# Copyright (c) Vispy Development Team. All Rights Reserved.
# Distributed under the (new) BSD License. See LICENSE.txt for more info.
# -----------------------------------------------------------------------------

from .globject import GLObject
from .texture import Texture2D
from .wrappers import _check_valid, read_pixels
from .context import get_current_canvas

# ------------------------------------------------------ RenderBuffer class ---

class RenderBuffer(GLObject):

    _GLIR_TYPE: str = ...

    def __init__(
        self,
        shape: tuple | None = None,
        format: None | Literal["color", "depth", "stencil"] = None,
        resizeable: bool = True,
    ): ...
    @property
    def shape(self): ...
    @property
    def format(self): ...
    def resize(
        self,
        shape: tuple[int, ...],
        format: None | Literal["color", "depth", "stencil"] = None,
    ): ...

# ------------------------------------------------------- FrameBuffer class ---
class FrameBuffer(GLObject):

    _GLIR_TYPE: str = ...

    def __init__(
        self,
        color: RenderBuffer | None = None,
        depth: RenderBuffer | None = None,
        stencil: RenderBuffer | None = None,
    ): ...
    def activate(self): ...
    def deactivate(self): ...
    def __enter__(self): ...
    def __exit__(self, t, val, trace): ...
    def _set_buffer(self, buffer, format): ...
    @property
    def color_buffer(self): ...
    @color_buffer.setter
    def color_buffer(self, buffer): ...
    @property
    def depth_buffer(self): ...
    @depth_buffer.setter
    def depth_buffer(self, buffer): ...
    @property
    def stencil_buffer(self): ...
    @stencil_buffer.setter
    def stencil_buffer(self, buffer): ...
    @property
    def shape(self): ...
    def resize(self, shape: tuple[int, int]): ...
    def read(self, mode: str = "color", alpha: bool = True, crop: ArrayLike | None = None) -> ArrayLike: ...



from .binary import (
    binary_erosion as binary_erosion,
    binary_dilation as binary_dilation,
    binary_opening as binary_opening,
    binary_closing as binary_closing,
)
from .gray import (
    erosion as erosion,
    dilation as dilation,
    opening as opening,
    closing as closing,
    white_tophat as white_tophat,
    black_tophat as black_tophat,
)
from .footprints import (
    square as square,
    rectangle as rectangle,
    diamond as diamond,
    disk as disk,
    cube as cube,
    octahedron as octahedron,
    ball as ball,
    octagon as octagon,
    star as star,
)
from ..measure._label import label as label
from ._skeletonize import (
    skeletonize as skeletonize,
    medial_axis as medial_axis,
    thin as thin,
    skeletonize_3d as skeletonize_3d,
)
from .convex_hull import (
    convex_hull_image as convex_hull_image,
    convex_hull_object as convex_hull_object,
)
from .grayreconstruct import reconstruction as reconstruction
from .misc import (
    remove_small_objects as remove_small_objects,
    remove_small_holes as remove_small_holes,
)
from .extrema import (
    h_minima as h_minima,
    h_maxima as h_maxima,
    local_maxima as local_maxima,
    local_minima as local_minima,
)
from ._flood_fill import flood as flood, flood_fill as flood_fill
from .max_tree import (
    max_tree as max_tree,
    area_opening as area_opening,
    area_closing as area_closing,
    diameter_opening as diameter_opening,
    diameter_closing as diameter_closing,
    max_tree_local_maxima as max_tree_local_maxima,
)

__all__ = [
    "binary_erosion",
    "binary_dilation",
    "binary_opening",
    "binary_closing",
    "erosion",
    "dilation",
    "opening",
    "closing",
    "white_tophat",
    "black_tophat",
    "square",
    "rectangle",
    "diamond",
    "disk",
    "cube",
    "octahedron",
    "ball",
    "octagon",
    "star",
    "label",
    "skeletonize",
    "skeletonize_3d",
    "thin",
    "medial_axis",
    "convex_hull_image",
    "convex_hull_object",
    "reconstruction",
    "remove_small_objects",
    "remove_small_holes",
    "h_minima",
    "h_maxima",
    "local_maxima",
    "local_minima",
    "flood",
    "flood_fill",
    "max_tree",
    "area_opening",
    "area_closing",
    "diameter_opening",
    "diameter_closing",
    "max_tree_local_maxima",
]



from typing import Any, Callable, ClassVar, Sequence, List
from operator import attrgetter as attrgetter
from contextlib import suppress as suppress
from abc import ABCMeta, abstractmethod
from ._available_if import available_if, _AvailableIfDescriptor
from ..base import BaseEstimator
import warnings
import numpy as np

__all__ = ["available_if", "if_delegate_has_method"]


class _BaseComposition(BaseEstimator, metaclass=ABCMeta):

    steps: ClassVar[List[Any]] = ...

    @abstractmethod
    def __init__(self) -> None:
        ...


# TODO(1.3) remove
class _IffHasAttrDescriptor(_AvailableIfDescriptor):
    def __init__(self, fn, delegate_names, attribute_name) -> None:
        ...


# TODO(1.3) remove
def if_delegate_has_method(delegate: tuple[str, ...] | str | Sequence[str]) -> Callable:
    ...



from vispy.util.event import Event
from vispy.app.canvas import Canvas

# -*- coding: utf-8 -*-
# Copyright (c) Vispy Development Team. All Rights Reserved.
# Distributed under the (new) BSD License. See LICENSE.txt for more info.

import numpy as np
from .linear import STTransform

class PanZoomTransform(STTransform):
    def __init__(self, canvas: None | Canvas = None, aspect: None | float = None, **kwargs): ...
    def attach(self, canvas: Canvas): ...
    @property
    def canvas_tr(self): ...
    def on_resize(self, event: Event): ...
    def on_mouse_move(self, event: Event): ...
    def on_mouse_wheel(self, event: Event): ...



# -*- coding: utf-8 -*-
# Copyright (c) Vispy Development Team. All Rights Reserved.
# Distributed under the (new) BSD License. See LICENSE.txt for more info.

from math import log
import os
from os import path as op
import sys
import shutil
import time

import urllib.request

from ..util.config import config

###############################################################################
# Vispy data directory

def load_data_file(fname: str, directory: str | None = None, force_download: str | bool = False) -> str: ...

###############################################################################
# File downloading (most adapted from mne-python)

class ProgressBar(object):

    spinner_symbols: list = ...
    template: str = ...

    def __init__(
        self,
        max_value: int,
        initial_value: int = 0,
        mesg: str = "",
        max_chars: int = 40,
        progress_character: str = ".",
        spinner: bool = False,
    ): ...
    def update(self, cur_value: float, mesg: str | None = None): ...
    def update_with_increment_value(self, increment_value: int, mesg: str | None = None): ...

def _chunk_read(response, local_file, chunk_size=65536, initial_size=0): ...
def _chunk_write(chunk, local_file, progress): ...
def _fetch_file(url, file_name, print_destination=True): ...
def sizeof_fmt(num): ...



# -*- coding: utf-8 -*-
# Copyright (c) Vispy Development Team. All Rights Reserved.
# Distributed under the (new) BSD License. See LICENSE.txt for more info.

from .base_filter import Filter as Filter  # noqa
from .clipper import Clipper as Clipper  # noqa
from .color import (
    Alpha as Alpha,
    ColorFilter as ColorFilter,
    IsolineFilter as IsolineFilter,
    ZColormapFilter as ZColormapFilter,
)  # noqa
from .picking import PickingFilter as PickingFilter  # noqa
from .mesh import (
    TextureFilter as TextureFilter,
    ShadingFilter as ShadingFilter,
    WireframeFilter as WireframeFilter,
)  # noqa



from typing import Callable


class ProjectionRegistry:
    def __init__(self) -> None: ...
    def register(self, *projections)-> None: ...
    def get_projection_class(self, name): ...
    def get_projection_names(self)-> list: ...

projection_registry: ProjectionRegistry = ...

def register_projection(cls)-> None: ...
def get_projection_class(projection=...): ...

get_projection_names: Callable = ...



from typing import Mapping
from ..classes.graph import Graph
from ..utils import not_implemented_for

__all__ = ["communicability", "communicability_exp"]

def communicability(G: Graph) -> dict[dict, dict]: ...
def communicability_exp(G: Graph) -> dict[dict, dict]: ...



from numpy.random import RandomState
from os import makedirs as makedirs, remove as remove
from ._base import RemoteFileMetadata as RemoteFileMetadata, load_descr as load_descr
from os.path import exists as exists
from numpy import ndarray
from ..utils._bunch import Bunch
from scipy.io import loadmat as loadmat
from .._typing import Int
from ..utils import check_random_state as check_random_state
from . import get_data_home as get_data_home

import numpy as np
import joblib

# The original data can be found at:
# https://cs.nyu.edu/~roweis/data/olivettifaces.mat
FACES = ...


def fetch_olivetti_faces(
    *,
    data_home: None | str = None,
    shuffle: bool = False,
    random_state: RandomState | None | Int = 0,
    download_if_missing: bool = True,
    return_X_y: bool = False,
) -> Bunch | tuple[Bunch, tuple] | tuple[ndarray, ndarray]:
    ...



# -*- coding: utf-8 -*-
# -----------------------------------------------------------------------------
# Copyright (c) Vispy Development Team. All Rights Reserved.
# Distributed under the (new) BSD License. See LICENSE.txt for more info.
# -----------------------------------------------------------------------------

from .glir import GlirQueue

class GLObject(object):

    # Type of GLIR object, reset in subclasses
    _GLIR_TYPE: str = ...

    # Internal id counter to keep track of GPU objects
    _idcount: int = ...

    def __init__(self): ...
    def __del__(self): ...
    def delete(self): ...
    @property
    def id(self): ...
    @property
    def glir(self): ...



from numpy.typing import NDArray

import numpy as np

from ._util import _validate_connectivity, _offsets_to_raveled_neighbors

unsigned_int_types: list = ...
signed_int_types: list = ...
signed_float_types: list = ...

# building the max tree.
def max_tree(image: NDArray, connectivity=1): ...
def area_opening(
    image: NDArray, area_threshold=64, connectivity=1, parent=None, tree_traverser=None
) -> NDArray: ...
def diameter_opening(
    image: NDArray,
    diameter_threshold=8,
    connectivity=1,
    parent=None,
    tree_traverser=None,
) -> NDArray: ...
def area_closing(
    image: NDArray, area_threshold=64, connectivity=1, parent=None, tree_traverser=None
) -> NDArray: ...
def diameter_closing(
    image: NDArray,
    diameter_threshold=8,
    connectivity=1,
    parent=None,
    tree_traverser=None,
) -> NDArray: ...
def max_tree_local_maxima(
    image: NDArray, connectivity=1, parent=None, tree_traverser=None
): ...



from ...classes.graph import Graph
from .boykovkolmogorov import boykov_kolmogorov
from .dinitz_alg import dinitz
from .edmondskarp import edmonds_karp
from .preflowpush import preflow_push
from .shortestaugmentingpath import shortest_augmenting_path
from .utils import build_flow_dict

# Define the default flow function for computing maximum flow.
default_flow_func = ...
# Functions that don't support cutoff for minimum cut computations.
flow_funcs: list = ...

__all__ = ["maximum_flow", "maximum_flow_value", "minimum_cut", "minimum_cut_value"]

def maximum_flow(
    flowG: Graph, _s, _t, capacity: str = "capacity", flow_func=None, **kwargs
): ...
def maximum_flow_value(
    flowG: Graph, _s, _t, capacity: str = "capacity", flow_func=None, **kwargs
): ...
def minimum_cut(
    flowG: Graph, _s, _t, capacity: str = "capacity", flow_func=None, **kwargs
): ...
def minimum_cut_value(
    flowG: Graph, _s, _t, capacity: str = "capacity", flow_func=None, **kwargs
): ...



from typing import Any

from django.db.backends.base.validation import (
    BaseDatabaseValidation as BaseDatabaseValidation,
)

class DatabaseValidation(BaseDatabaseValidation):
    def check_field_type(self, field: Any, field_type: Any) -> Any: ...



from collections.abc import Iterable
from numpy.typing import ArrayLike

from collections import Counter
from itertools import chain

from ..classes.graph import Graph
from ..classes.graphviews import reverse_view, subgraph_view
from ..utils import not_implemented_for, pairwise

__all__ = [
    "nodes",
    "edges",
    "degree",
    "degree_histogram",
    "neighbors",
    "number_of_nodes",
    "number_of_edges",
    "density",
    "is_directed",
    "info",
    "freeze",
    "is_frozen",
    "subgraph",
    "subgraph_view",
    "induced_subgraph",
    "reverse_view",
    "edge_subgraph",
    "restricted_view",
    "to_directed",
    "to_undirected",
    "add_star",
    "add_path",
    "add_cycle",
    "create_empty_copy",
    "set_node_attributes",
    "get_node_attributes",
    "set_edge_attributes",
    "get_edge_attributes",
    "all_neighbors",
    "non_neighbors",
    "non_edges",
    "common_neighbors",
    "is_weighted",
    "is_negatively_weighted",
    "is_empty",
    "selfloop_edges",
    "nodes_with_selfloops",
    "number_of_selfloops",
    "path_weight",
    "is_path",
]

def nodes(G: Graph): ...
def edges(G: Graph, nbunch=None): ...
def degree(G: Graph, nbunch=None, weight=None): ...
def neighbors(G: Graph, n): ...
def number_of_nodes(G: Graph): ...
def number_of_edges(G: Graph): ...
def density(G: Graph): ...
def degree_histogram(G: Graph) -> ArrayLike: ...
def is_directed(G: Graph): ...
def frozen(*args, **kwargs): ...
def freeze(G: Graph): ...
def is_frozen(G: Graph): ...
def add_star(G_to_add_to, nodes_for_star, **attr): ...
def add_path(G_to_add_to, nodes_for_path, **attr): ...
def add_cycle(G_to_add_to, nodes_for_cycle, **attr): ...
def subgraph(G: Graph, nbunch: ArrayLike | Iterable): ...
def induced_subgraph(G: Graph, nbunch): ...
def edge_subgraph(G: Graph, edges: Iterable): ...
def restricted_view(G: Graph, nodes: Iterable, edges: Iterable): ...
def to_directed(graph): ...
def to_undirected(graph): ...
def create_empty_copy(G: Graph, with_data=True): ...
def info(G: Graph, n=None) -> str: ...
def set_node_attributes(G: Graph, values, name=None): ...
def get_node_attributes(G: Graph, name: str): ...
def set_edge_attributes(G: Graph, values, name=None): ...
def get_edge_attributes(G: Graph, name: str): ...
def all_neighbors(graph, node): ...
def non_neighbors(graph, node): ...
def non_edges(graph): ...
def common_neighbors(G: Graph, u, v): ...
def is_weighted(
    G: Graph, edge: tuple | None = None, weight: str = "weight"
) -> bool: ...
def is_negatively_weighted(
    G: Graph, edge: tuple | None = None, weight: str = "weight"
) -> bool: ...
def is_empty(G: Graph) -> bool: ...
def nodes_with_selfloops(G: Graph): ...
def selfloop_edges(G: Graph, data=False, keys=False, default=None): ...
def number_of_selfloops(G: Graph) -> int: ...
def is_path(G: Graph, path: ArrayLike) -> bool: ...
def path_weight(G: Graph, path: ArrayLike, weight: str) -> int | float: ...



from vispy.util.event import Event
from vispy._typing import Scalar

# -*- coding: utf-8 -*-
# Copyright (c) Vispy Development Team. All Rights Reserved.
# Distributed under the (new) BSD License. See LICENSE.txt for more info.

import math
import numpy as np

from .base_camera import BaseCamera
from ...util import keys, transforms
from ...visuals.transforms import MatrixTransform

class PerspectiveCamera(BaseCamera):

    _state_props = ...

    def __init__(self, fov: float = 60.0, scale_factor: Scalar | None = None, center=None, **kwargs): ...
    def viewbox_mouse_event(self, event: Event): ...
    @property
    def scale_factor(self): ...
    @scale_factor.setter
    def scale_factor(self, value): ...
    @property
    def near_clip_distance(self): ...
    def _set_range(self, init): ...
    def viewbox_resize_event(self, event: Event): ...
    def _update_transform(self, event=None): ...
    def _update_projection_transform(self, fx, fy): ...

class Base3DRotationCamera(PerspectiveCamera):
    def __init__(self, fov=0.0, **kwargs): ...
    @property
    def distance(self): ...
    @distance.setter
    def distance(self, distance): ...
    def viewbox_mouse_event(self, event: Event): ...
    def _update_camera_pos(self): ...
    def _get_dim_vectors(self): ...
    def _update_projection_transform(self, fx, fy): ...
    def _update_rotation(self, event): ...
    def _rotate_tr(self): ...
    def _dist_to_trans(self, dist): ...



from typing import ClassVar
from scipy.special import expit as expit, logit as logit
from scipy.stats import gmean as gmean
from abc import ABC, abstractmethod
from dataclasses import dataclass
from numpy import ndarray
from ..utils.extmath import softmax as softmax
from .._typing import ArrayLike, Float

import numpy as np


@dataclass
class Interval:
    low: ClassVar[float] = ...
    high: ClassVar[float] = ...
    low_inclusive: ClassVar[bool] = ...
    high_inclusive: ClassVar[bool] = ...

    def __post_init__(self) -> None:
        ...

    def includes(self, x: ArrayLike) -> bool:
        ...


class BaseLink(ABC):

    is_multiclass: ClassVar[bool] = ...  # used for testing only

    # Usually, raw_prediction may be any real number and y_pred is an open
    # interval.
    # interval_raw_prediction = Interval(-np.inf, np.inf, False, False)
    interval_y_pred = ...

    @abstractmethod
    def link(self, y_pred: ArrayLike, out: None | ArrayLike = None) -> ndarray:
        ...

    @abstractmethod
    def inverse(
        self, raw_prediction: ArrayLike, out: None | ArrayLike = None
    ) -> ndarray:
        ...


class IdentityLink(BaseLink):
    def link(
        self, y_pred: ArrayLike | Float, out: None | ArrayLike = None
    ) -> ndarray | Float:
        ...

    def inverse(
        self, y_pred: ArrayLike | Float, out: None | ArrayLike = None
    ) -> ndarray | Float:
        ...


class LogLink(BaseLink):

    interval_y_pred = ...

    def link(
        self, y_pred: ArrayLike | Float, out: None | ArrayLike = None
    ) -> ndarray | Float:
        ...

    def inverse(
        self, raw_prediction: ArrayLike, out: None | ArrayLike = None
    ) -> ndarray:
        ...


class LogitLink(BaseLink):

    interval_y_pred = ...

    def link(
        self, y_pred: ArrayLike | Float, out: None | ArrayLike = None
    ) -> ndarray | Float:
        ...

    def inverse(
        self, raw_prediction: ArrayLike, out: None | ArrayLike = None
    ) -> ndarray:
        ...


class MultinomialLogit(BaseLink):

    is_multiclass: ClassVar[bool] = ...
    interval_y_pred = ...

    def symmetrize_raw_prediction(self, raw_prediction):
        ...

    def link(self, y_pred: ArrayLike, out: None | ArrayLike = None) -> ndarray:
        ...

    def inverse(
        self, raw_prediction: ArrayLike, out: None | ArrayLike = None
    ) -> ndarray:
        ...


_LINKS: dict = ...



from ..classes.reportviews import MultiEdgeView, MultiDegreeView
from typing import Mapping
from ..classes.multidigraph import MultiDiGraph
from ..classes.graph import Graph
from copy import deepcopy
from functools import cached_property

from ..classes.graph import Graph
import networkx.convert as convert
from networkx import NetworkXError
from ..classes.coreviews import MultiAdjacencyView
from ..classes.graph import Graph
from ..classes.reportviews import MultiDegreeView, MultiEdgeView

__all__ = ["MultiGraph"]

class MultiGraph(Graph):

    # node_dict_factory = dict    # already assigned in Graph
    # adjlist_outer_dict_factory = dict
    # adjlist_inner_dict_factory = dict
    edge_key_dict_factory = ...
    # edge_attr_dict_factory = dict

    def to_directed_class(self): ...
    def to_undirected_class(self): ...
    def __init__(self, incoming_graph_data=None, multigraph_input=None, **attr): ...
    @cached_property
    def adj(self): ...
    def new_edge_key(self, u, v) -> int: ...
    def add_edge(self, u_for_edge, v_for_edge, key=None, **attr): ...
    def add_edges_from(self, ebunch_to_add, **attr): ...
    def remove_edge(self, u, v, key=None): ...
    def remove_edges_from(self, ebunch): ...
    def has_edge(self, u, v, key=None) -> bool: ...
    @cached_property
    def edges(self) -> MultiEdgeView: ...
    def get_edge_data(self, u, v, key=None, default=None) -> Mapping: ...
    @cached_property
    def degree(self) -> MultiDegreeView | int: ...
    def is_multigraph(self): ...
    def is_directed(self): ...
    def copy(self, as_view=False) -> Graph: ...
    def to_directed(self, as_view=False) -> MultiDiGraph: ...
    def to_undirected(self, as_view=False): ...
    def number_of_edges(self, u=None, v=None) -> int: ...



from typing import Any, List, Optional

from django.apps import apps as apps
from django.core.management.base import BaseCommand as BaseCommand
from django.core.management.base import CommandError as CommandError
from django.core.management.base import no_translations as no_translations
from django.core.management.sql import (
    emit_post_migrate_signal as emit_post_migrate_signal,
)
from django.core.management.sql import (
    emit_pre_migrate_signal as emit_pre_migrate_signal,
)
from django.db import DEFAULT_DB_ALIAS as DEFAULT_DB_ALIAS
from django.db import connections as connections
from django.db import router as router
from django.db.migrations.autodetector import (
    MigrationAutodetector as MigrationAutodetector,
)
from django.db.migrations.executor import MigrationExecutor as MigrationExecutor
from django.db.migrations.loader import AmbiguityError as AmbiguityError
from django.db.migrations.operations.base import Operation
from django.db.migrations.state import ModelState as ModelState
from django.db.migrations.state import ProjectState as ProjectState
from django.utils.module_loading import module_has_submodule as module_has_submodule
from django.utils.text import Truncator as Truncator

class Command(BaseCommand):
    verbosity: int = ...
    interactive: bool = ...
    start: float = ...
    def migration_progress_callback(
        self, action: str, migration: Optional[Any] = ..., fake: bool = ...
    ) -> None: ...
    def sync_apps(self, connection: Any, app_labels: List[str]) -> None: ...
    @staticmethod
    def describe_operation(operation: Operation, backwards: bool) -> str: ...



"""
This type stub file was generated by pyright.
"""

from pathlib import Path
from traitlets.config.configurable import LoggingConfigurable
from traitlets import observe

"""An object for managing IPython profile directories."""
class ProfileDirError(Exception):
    ...


class ProfileDir(LoggingConfigurable):
    """An object to manage the profile directory and its resources.

    The profile directory is used by all IPython applications, to manage
    configuration, logging and security.

    This object knows how to find, create and manage these directories. This
    should be used by any code that wants to handle profiles.
    """
    security_dir_name = ...
    log_dir_name = ...
    startup_dir_name = ...
    pid_dir_name = ...
    static_dir_name = ...
    security_dir = ...
    log_dir = ...
    startup_dir = ...
    pid_dir = ...
    static_dir = ...
    location = ...
    _location_isset = ...
    @observe('log_dir')
    def check_log_dir(self, change=...): # -> None:
        ...
    
    @observe('startup_dir')
    def check_startup_dir(self, change=...): # -> None:
        ...
    
    @observe('security_dir')
    def check_security_dir(self, change=...): # -> None:
        ...
    
    @observe('pid_dir')
    def check_pid_dir(self, change=...): # -> None:
        ...
    
    def check_dirs(self): # -> None:
        ...
    
    def copy_config_file(self, config_file: str, path: Path, overwrite=...) -> bool:
        """Copy a default config file into the active profile directory.

        Default configuration files are kept in :mod:`IPython.core.profile`.
        This function moves these from that location to the working profile
        directory.
        """
        ...
    
    @classmethod
    def create_profile_dir(cls, profile_dir, config=...):
        """Create a new profile directory given a full path.

        Parameters
        ----------
        profile_dir : str
            The full path to the profile directory.  If it does exist, it will
            be used.  If not, it will be created.
        """
        ...
    
    @classmethod
    def create_profile_dir_by_name(cls, path, name=..., config=...):
        """Create a profile dir by profile name and path.

        Parameters
        ----------
        path : unicode
            The path (directory) to put the profile directory in.
        name : unicode
            The name of the profile.  The name of the profile directory will
            be "profile_<profile>".
        """
        ...
    
    @classmethod
    def find_profile_dir_by_name(cls, ipython_dir, name=..., config=...):
        """Find an existing profile dir by profile name, return its ProfileDir.

        This searches through a sequence of paths for a profile dir.  If it
        is not found, a :class:`ProfileDirError` exception will be raised.

        The search path algorithm is:
        1. ``os.getcwd()`` # removed for security reason.
        2. ``ipython_dir``

        Parameters
        ----------
        ipython_dir : unicode or str
            The IPython directory to use.
        name : unicode or str
            The name of the profile.  The name of the profile directory
            will be "profile_<profile>".
        """
        ...
    
    @classmethod
    def find_profile_dir(cls, profile_dir, config=...):
        """Find/create a profile dir and return its ProfileDir.

        This will create the profile directory if it doesn't exist.

        Parameters
        ----------
        profile_dir : unicode or str
            The path of the profile directory.
        """
        ...
    





# Python: 3.8.2 (tags/v3.8.2:7b3ab59, Feb 25 2020, 23:03:10) [MSC v.1916 64 bit (AMD64)]
# Library: scipy, version: 1.6.2
# Module: scipy.sparse.linalg.dsolve._superlu, version: unspecified
import typing
import builtins as _mod_builtins

SuperLU = _mod_builtins.SuperLU
__doc__: typing.Any
__file__: str
__name__: str
__package__: str
def gssv() -> typing.Any:
    'Direct inversion of sparse matrix.\n\nX = gssv(A,B) solves A*X = B for X.'
    ...

def gstrf() -> typing.Any:
    "gstrf(A, ...)\n\nperforms a factorization of the sparse matrix A=*(N,nnz,nzvals,rowind,colptr) and \nreturns a factored_lu object.\n\narguments\n---------\n\nMatrix to be factorized is represented as N,nnz,nzvals,rowind,colptr\n  as separate arguments.  This is compressed sparse column representation.\n\nN         number of rows and columns \nnnz       number of non-zero elements\nnzvals    non-zero values \nrowind    row-index for this column (same size as nzvals)\ncolptr    index into rowind for first non-zero value in this column\n          size is (N+1).  Last value should be nnz. \n\nadditional keyword arguments:\n-----------------------------\noptions             specifies additional options for SuperLU\n                    (same keys and values as in superlu_options_t C structure,\n                    and additionally 'Relax' and 'PanelSize')\n\nilu                 whether to perform an incomplete LU decomposition\n                    (default: false)\n"
    ...

def __getattr__(name) -> typing.Any:
    ...




"""
This type stub file was generated by pyright.
"""

from typing import Optional
from prompt_toolkit.buffer import Buffer
from prompt_toolkit.key_binding import KeyPressEvent
from prompt_toolkit.auto_suggest import AutoSuggestFromHistory, Suggestion
from prompt_toolkit.document import Document
from prompt_toolkit.history import History
from prompt_toolkit.shortcuts import PromptSession
from prompt_toolkit.layout.processors import Processor, Transformation, TransformationInput

class AppendAutoSuggestionInAnyLine(Processor):
    """
    Append the auto suggestion to lines other than the last (appending to the
    last line is natively supported by the prompt toolkit).
    """
    def __init__(self, style: str = ...) -> None:
        ...
    
    def apply_transformation(self, ti: TransformationInput) -> Transformation:
        ...
    


class NavigableAutoSuggestFromHistory(AutoSuggestFromHistory):
    """
    A subclass of AutoSuggestFromHistory that allow navigation to next/previous
    suggestion from history. To do so it remembers the current position, but it
    state need to carefully be cleared on the right events.
    """
    def __init__(self) -> None:
        ...
    
    def reset_history_position(self, _: Buffer): # -> None:
        ...
    
    def disconnect(self): # -> None:
        ...
    
    def connect(self, pt_app: PromptSession): # -> None:
        ...
    
    def get_suggestion(self, buffer: Buffer, document: Document) -> Optional[Suggestion]:
        ...
    
    def up(self, query: str, other_than: str, history: History) -> None:
        ...
    
    def down(self, query: str, other_than: str, history: History) -> None:
        ...
    


def accept_or_jump_to_end(event: KeyPressEvent): # -> None:
    """Apply autosuggestion or jump to end of line."""
    ...

def accept(event: KeyPressEvent): # -> None:
    """Accept autosuggestion"""
    ...

def discard(event: KeyPressEvent): # -> None:
    """Discard autosuggestion"""
    ...

def accept_word(event: KeyPressEvent): # -> None:
    """Fill partial autosuggestion by word"""
    ...

def accept_character(event: KeyPressEvent): # -> None:
    """Fill partial autosuggestion by character"""
    ...

def accept_and_keep_cursor(event: KeyPressEvent): # -> None:
    """Accept autosuggestion and keep cursor in place"""
    ...

def accept_and_move_cursor_left(event: KeyPressEvent): # -> None:
    """Accept autosuggestion and move cursor left in place"""
    ...

def backspace_and_resume_hint(event: KeyPressEvent): # -> None:
    """Resume autosuggestions after deleting last character"""
    ...

def resume_hinting(event: KeyPressEvent): # -> None:
    """Resume autosuggestions"""
    ...

def up_and_update_hint(event: KeyPressEvent): # -> None:
    """Go up and update hint"""
    ...

def down_and_update_hint(event: KeyPressEvent): # -> None:
    """Go down and update hint"""
    ...

def accept_token(event: KeyPressEvent): # -> None:
    """Fill partial autosuggestion by token"""
    ...

Provider = ...
def swap_autosuggestion_up(event: KeyPressEvent): # -> None:
    """Get next autosuggestion from history."""
    ...

def swap_autosuggestion_down(event: KeyPressEvent): # -> None:
    """Get previous autosuggestion from history."""
    ...

def __getattr__(key): # -> (event: KeyPressEvent) -> None:
    ...




from typing import Literal, Sequence
from ._typing import *
from .colors import Normalize
from .colors import Colormap
from .axes import Axes

__all__ = ["streamplot"]

def streamplot(
    axes: Axes,
    x: ArrayLike,
    y: ArrayLike,
    u: ArrayLike,
    v: ArrayLike,
    density: float = ...,
    linewidth: float = ...,
    color: Color = ...,
    cmap: Colormap = ...,
    norm: Normalize = ...,
    arrowsize: float = ...,
    arrowstyle: str = ...,
    minlength: float = ...,
    transform=...,
    zorder: int = ...,
    start_points: ArrayLike = ...,
    maxlength: float = ...,
    integration_direction: Literal["forward", "backward", "both"] = ...,
    broken_streamlines: bool = ...,
) -> StreamplotSet: ...

class StreamplotSet:
    def __init__(self, lines, arrows) -> None: ...

class DomainMap:
    def __init__(self, grid: Grid, mask: StreamMask) -> None: ...
    def grid2mask(self, xi, yi): ...
    def mask2grid(self, xm, ym): ...
    def data2grid(self, xd, yd): ...
    def grid2data(self, xg, yg): ...
    def start_trajectory(self, xg, yg, broken_streamlines=...): ...
    def reset_start_point(self, xg, yg): ...
    def update_trajectory(self, xg, yg, broken_streamlines=...): ...
    def undo_trajectory(self) -> None: ...

class Grid:
    def __init__(self, x, y) -> None: ...
    @property
    def shape(self) -> tuple[int, int]: ...
    def within_grid(self, xi, yi): ...

class StreamMask:
    def __init__(self, density: float | Sequence[float]) -> None: ...
    def __getitem__(self, args): ...

class InvalidIndexError(Exception): ...
class TerminateTrajectory(Exception): ...

def get_integrator(u, v, dmap, minlength, maxlength, integration_direction): ...

class OutOfBounds(IndexError): ...

def interpgrid(a, xi, yi): ...



from typing import Literal
from ..utils.sparsefuncs import count_nonzero as count_nonzero
from scipy.stats import rankdata as rankdata
from ..preprocessing import label_binarize as label_binarize
from ..exceptions import UndefinedMetricWarning as UndefinedMetricWarning
from ..utils.extmath import stable_cumsum as stable_cumsum
from numpy import ndarray
from ..utils.multiclass import type_of_target as type_of_target
from functools import partial as partial
from scipy.sparse import csr_matrix as csr_matrix, issparse as issparse
from .._typing import ArrayLike, Float, MatrixLike, Int
from ..utils import (
    assert_all_finite as assert_all_finite,
    check_consistent_length as check_consistent_length,
    column_or_1d as column_or_1d,
    check_array as check_array,
)

# Authors: Alexandre Gramfort <alexandre.gramfort@inria.fr>
#          Mathieu Blondel <mathieu@mblondel.org>
#          Olivier Grisel <olivier.grisel@ensta.org>
#          Arnaud Joly <a.joly@ulg.ac.be>
#          Jochen Wersdorfer <jochen@wersdoerfer.de>
#          Lars Buitinck
#          Joel Nothman <joel.nothman@gmail.com>
#          Noel Dawe <noel@dawe.me>
#          Michal Karbownik <michakarbownik@gmail.com>
# License: BSD 3 clause


import warnings

import numpy as np


def auc(x: ArrayLike, y: ArrayLike) -> Float:
    ...


def average_precision_score(
    y_true: MatrixLike | ArrayLike,
    y_score: MatrixLike | ArrayLike,
    *,
    average: None | Literal["micro", "samples", "weighted", "macro", "macro"] = "macro",
    pos_label: str | Int = 1,
    sample_weight: None | ArrayLike = None,
) -> Float:
    ...


def det_curve(
    y_true: ArrayLike,
    y_score: ArrayLike,
    pos_label: None | str | Int = None,
    sample_weight: None | ArrayLike = None,
) -> tuple[ndarray, ndarray, ndarray]:
    ...


def roc_auc_score(
    y_true: MatrixLike | ArrayLike,
    y_score: MatrixLike | ArrayLike,
    *,
    average: Literal["micro", "macro", "samples", "weighted", "macro"] | None = "macro",
    sample_weight: None | ArrayLike = None,
    max_fpr: float | None = None,
    multi_class: Literal["raise", "ovr", "ovo", "raise"] = "raise",
    labels: None | ArrayLike = None,
) -> Float:
    ...


def precision_recall_curve(
    y_true: ArrayLike,
    probas_pred: ArrayLike,
    *,
    pos_label: None | str | Int = None,
    sample_weight: None | ArrayLike = None,
) -> tuple[ndarray, ndarray, ndarray]:
    ...


def roc_curve(
    y_true: ArrayLike,
    y_score: ArrayLike,
    *,
    pos_label: None | str | Int = None,
    sample_weight: None | ArrayLike = None,
    drop_intermediate: bool = True,
) -> tuple[ndarray, ndarray, ndarray]:
    ...


def label_ranking_average_precision_score(
    y_true: MatrixLike, y_score: MatrixLike, *, sample_weight: None | ArrayLike = None
) -> float:
    ...


def coverage_error(
    y_true: MatrixLike, y_score: MatrixLike, *, sample_weight: None | ArrayLike = None
) -> float:
    ...


def label_ranking_loss(
    y_true: MatrixLike, y_score: MatrixLike, *, sample_weight: None | ArrayLike = None
) -> float:
    ...


def dcg_score(
    y_true: MatrixLike,
    y_score: MatrixLike,
    *,
    k: None | Int = None,
    log_base: Float = 2,
    sample_weight: None | ArrayLike = None,
    ignore_ties: bool = False,
) -> float:
    ...


def ndcg_score(
    y_true: MatrixLike,
    y_score: MatrixLike,
    *,
    k: None | Int = None,
    sample_weight: None | ArrayLike = None,
    ignore_ties: bool = False,
) -> float:
    ...


def top_k_accuracy_score(
    y_true: ArrayLike,
    y_score: MatrixLike | ArrayLike,
    *,
    k: Int = 2,
    normalize: bool = True,
    sample_weight: None | ArrayLike = None,
    labels: None | ArrayLike = None,
) -> float:
    ...



from typing import Mapping
import warnings
from collections import deque
from heapq import heappop, heappush
from itertools import count

from ...classes.graph import Graph
from ...utils import py_random_state
from ...utils.decorators import not_implemented_for

__all__ = ["betweenness_centrality", "edge_betweenness_centrality", "edge_betweenness"]

@py_random_state(5)
def betweenness_centrality(
    G: Graph,
    k=None,
    normalized: bool = True,
    weight=None,
    endpoints: bool = False,
    seed=None,
) -> Mapping: ...
@py_random_state(4)
def edge_betweenness_centrality(
    G: Graph, k=None, normalized: bool = True, weight=None, seed=None
) -> Mapping: ...

# obsolete name
def edge_betweenness(G: Graph, k=None, normalized=True, weight=None, seed=None): ...



from typing import Any, ClassVar, Literal, TypeVar
from scipy import linalg as linalg
from numpy import ndarray
from ..utils.extmath import fast_logdet as fast_logdet
from .. import config_context as config_context
from ..base import BaseEstimator
from ..metrics.pairwise import pairwise_distances as pairwise_distances
from .._typing import MatrixLike, Float, ArrayLike
from ..utils import check_array as check_array

EmpiricalCovariance_Self = TypeVar(
    "EmpiricalCovariance_Self", bound="EmpiricalCovariance"
)


# Author: Alexandre Gramfort <alexandre.gramfort@inria.fr>
#         Gael Varoquaux <gael.varoquaux@normalesup.org>
#         Virgile Fritsch <virgile.fritsch@inria.fr>
#
# License: BSD 3 clause

# avoid division truncation
import warnings
import numpy as np


def log_likelihood(emp_cov: MatrixLike, precision: MatrixLike) -> Float:
    ...


def empirical_covariance(X: ArrayLike, *, assume_centered: bool = False) -> ndarray:
    ...


class EmpiricalCovariance(BaseEstimator):
    feature_names_in_: ndarray = ...
    n_features_in_: int = ...
    precision_: ndarray = ...
    covariance_: ndarray = ...
    location_: ndarray = ...

    _parameter_constraints: ClassVar[dict] = ...

    def __init__(
        self, *, store_precision: bool = True, assume_centered: bool = False
    ) -> None:
        ...

    def get_precision(self) -> ndarray:
        ...

    def fit(
        self: EmpiricalCovariance_Self, X: MatrixLike, y: Any = None
    ) -> EmpiricalCovariance_Self:
        ...

    def score(self, X_test: MatrixLike, y: Any = None) -> Float:
        ...

    def error_norm(
        self,
        comp_cov: MatrixLike,
        norm: Literal["frobenius", "spectral", "frobenius"] = "frobenius",
        scaling: bool = True,
        squared: bool = True,
    ) -> Float:
        ...

    def mahalanobis(self, X: MatrixLike) -> ndarray:
        ...



from typing import Callable

from . import isomorphvf2 as vf2
from ...classes.graph import Graph

__all__ = ["GraphMatcher", "DiGraphMatcher", "MultiGraphMatcher", "MultiDiGraphMatcher"]

class GraphMatcher(vf2.GraphMatcher):
    def __init__(
        self,
        G1: Graph,
        G2: Graph,
        node_match: Callable | None = None,
        edge_match: Callable | None = None,
    ): ...

    semantic_feasibility = ...

class DiGraphMatcher(vf2.DiGraphMatcher):
    def __init__(
        self,
        G1: Graph,
        G2: Graph,
        node_match: Callable | None = None,
        edge_match: Callable | None = None,
    ): ...
    def semantic_feasibility(self, G1_node, G2_node): ...

# The "semantics" of edge_match are different for multi(di)graphs, but
# the implementation is the same.  So, technically we do not need to
# provide "multi" versions, but we do so to match NetworkX's base classes.

class MultiGraphMatcher(GraphMatcher):
    pass

class MultiDiGraphMatcher(DiGraphMatcher):
    pass



from numpy.typing import ArrayLike

__all__ = [
    "generate_edgelist",
    "write_edgelist",
    "parse_edgelist",
    "read_edgelist",
    "read_weighted_edgelist",
    "write_weighted_edgelist",
]

from ..classes.graph import Graph
from ..utils import open_file

def generate_edgelist(G: Graph, delimiter: str = " ", data=True) -> str: ...
def write_edgelist(
    G: Graph,
    path,
    comments: str = "#",
    delimiter: str = " ",
    data: bool | ArrayLike = True,
    encoding: str = "utf-8",
): ...
def parse_edgelist(
    lines,
    comments: str = "#",
    delimiter: str | None = None,
    create_using=None,
    nodetype=None,
    data=True,
): ...
def read_edgelist(
    path,
    comments: str = "#",
    delimiter: str | None = None,
    create_using=None,
    nodetype=None,
    data=True,
    edgetype=None,
    encoding: str = "utf-8",
): ...
def write_weighted_edgelist(
    G: Graph, path, comments: str = "#", delimiter: str = " ", encoding: str = "utf-8"
): ...
def read_weighted_edgelist(
    path,
    comments: str = "#",
    delimiter: str | None = None,
    create_using=None,
    nodetype=None,
    encoding: str = "utf-8",
): ...



from vispy.util.svg.color import Color
from typing import Mapping, Any
from numpy.typing import ArrayLike

# -*- coding: utf-8 -*-
# -----------------------------------------------------------------------------
# Copyright (c) Vispy Development Team. All Rights Reserved.
# Distributed under the (new) BSD License. See LICENSE.txt for more info.
# -----------------------------------------------------------------------------

##############################################################################
# Load font into texture

import numpy as np
from copy import deepcopy
import sys

from ._sdf_gpu import SDFRendererGPU
from ...gloo import TextureAtlas, IndexBuffer, VertexBuffer
from ...gloo import context
from ...gloo.wrappers import _check_valid
from ..transforms import STTransform
from ...color import ColorArray
from ..visual import Visual
from ...io import load_spatial_filters

class TextureFont(object):
    def __init__(self, font: Mapping, renderer: SDFRendererGPU): ...
    @property
    def ratio(self): ...
    @property
    def slop(self): ...
    def __getitem__(self, char): ...
    def _load_char(self, char): ...

class FontManager(object):

    # XXX: should store a font-manager on each context,
    # or let TextureFont use a TextureAtlas for each context
    def __init__(self, method="cpu"): ...
    def get_font(self, face, bold=False, italic=False): ...

##############################################################################
# The visual

_VERTEX_SHADER: str = ...

_FRAGMENT_SHADER: str = ...

def _text_to_vbo(text, font, anchor_x, anchor_y, lowres_size): ...

class TextVisual(Visual):

    _shaders: dict = ...

    def __init__(
        self,
        text: str | ArrayLike | None = None,
        color: Color | str = "black",
        bold: bool = False,
        italic: bool = False,
        face: str = "OpenSans",
        font_size: float = 12,
        pos=[0, 0, 0],
        rotation: float = 0.0,
        anchor_x: str = "center",
        anchor_y: str = "center",
        method: str = "cpu",
        font_manager: Any | None = None,
        depth_test: bool = False,
    ): ...
    @property
    def text(self): ...
    @text.setter
    def text(self, text): ...
    @property
    def anchors(self): ...
    @anchors.setter
    def anchors(self, a): ...
    @property
    def font_size(self): ...
    @font_size.setter
    def font_size(self, size): ...
    @property
    def color(self): ...
    @color.setter
    def color(self, color): ...
    @property
    def rotation(self): ...
    @rotation.setter
    def rotation(self, rotation): ...
    @property
    def pos(self): ...
    @pos.setter
    def pos(self, pos): ...
    def _prepare_draw(self, view): ...
    def _prepare_transforms(self, view): ...
    def _compute_bounds(self, axis, view): ...
    @property
    def face(self): ...
    @face.setter
    def face(self, value): ...
    @property
    def bold(self): ...
    @bold.setter
    def bold(self, value): ...
    @property
    def italic(self): ...
    @italic.setter
    def italic(self, value): ...
    def _update_font(self): ...

class SDFRendererCPU(object):

    # This should probably live in _sdf_cpu.pyx, but doing so makes
    # debugging substantially more annoying
    def render_to_texture(self, data, texture, offset, size): ...
